<?php
/**
 * Class AdvancedFields
 *
 * Abstract class for managing advanced fields with styles.
 *
 * @package RexTheme\Checkoutify\Abstracts
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\Abstracts;


/**
 * Class AdvancedFields
 *
 * Abstract class for managing advanced fields with styles.
 *
 * @package RexTheme\Checkoutify\Abstracts
 * @since 1.0.0
 */
 abstract class AdvancedFields {

    /**
     * CSS properties.
     *
     * @var array
     * @since 1.0.0
     */
    public $properties = [];

    /**
     * Supported styles.
     *
     * @var array
     * @since 1.0.0
     */
    public $supportedStyles = [];

    /**
     * Get field.
     *
     * This method should be implemented by the extending classes to retrieve a field.
     *
     * @return mixed Field data.
     * @since 1.0.0
     */
    abstract function getField();
    

    /**
     * Get supported style properties
     * 
     * @return  array
     * @since 1.0.0 
     */
    public function getSupportedStyles(){
        $styles =  [
            'box',
            'button',
            'checkbox',
            'input',
            'label',
            'product',
            'radio',
            'section',
            'shipping',
            'subTotal',
            'total',
        ];

        /**
		 * Apply a filter to allow modification or addition of supported styles.
		 *
		 * @param array $styles
		 *
		 * @return array $styles
		 * @since 1.0.0
		 */
        return apply_filters( 'checkoutify_supported_styles', $styles );
    }


    /**
     * Get styles.
     *
     * Retrieves CSS styles for supported styles.
     *
     * @param array $supportedStyles Array of supported styles.
     * @return array Associative array containing styles for supported styles.
     * @since 1.0.0
     */
    public function getStyles( $supportedStyles=[] ){
        $styles = [];
        foreach( $supportedStyles as $supportedStyle ){
            if( in_array($supportedStyle, $this->getSupportedStyles()) ){
                $className = "\\RexTheme\\Checkoutify\\Module\Style\\".ucfirst($supportedStyle);
                if ( class_exists( $className ) ) {
                    $styleInstance = new $className();
                    $styles[$supportedStyle] = $styleInstance->getProperties();
                }
            }
        }
        return $styles;
    }
 }