<?php
/**
 * Controller
 *
 * @package RexTheme\Checkoutify\Abstracts
 * @version 1.0.0
 * @author A S M Nasim
 */

namespace RexTheme\Checkoutify\Abstracts;

use WP_REST_Controller;

/**
 * Rest Controller base class.
 *
 * @since 0.3.0
 */
abstract class RESTController extends WP_REST_Controller {

	/**
	 * Endpoint namespace.
	 *
	 * @var string
	 */
	protected $namespace = 'checkoutify/v1';

	/**
	 * Check default permission for rest routes.
	 *
	 * @since 0.3.0
	 *
	 * Manage permissions from capabilities.
	 *
	 * @return bool
	 */
	public function checkPermission(): bool {
		return true;
	}


	/**
	 * Create a WP_Error object with the specified parameters.
	 *
	 * @param string $error_code    The error code.
	 * @param string $error_message The error message.
	 * @param int    $data          The HTTP status code.
	 *
	 * @return WP_Error The created WP_Error object.
	 *
	 * @since 1.0.0
	 */
	protected function prepareWpErrorResponse( $error_code, $error_message, $data ) {
		return new WP_Error(
			$error_code,
			$error_message,
			$data
		);
	}


	/**
	 * Retrieves the group schema, conforming to JSON Schema.
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function getCollectionParams() {
		return array();
	}
}
