<?php
/**
 * File Description
 *
 * Provide a brief description of the purpose of this file, what it contains,
 * and any other relevant information.
 *
 * @package RexTheme\Checkoutify\Admin
 * @version 1.0.0
 * @author A S M Nasim
 */

namespace RexTheme\Checkoutify\Admin;

use RexTheme\Checkoutify\Common\Keys;

/**
 * Class Hook
 *
 * This class manages hooks and actions in the WordPress admin panel for Checkoutify.
 *
 * @since 1.0.0
 */
class Hooks {

	/**
	 * Hook constructor.
	 *
	 * Initializes the class and adds necessary actions for the WordPress admin panel.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {

		// Add action to execute 'hideNotice' method in the WordPress admin head.
		add_action( 'admin_head', array( $this, 'hideNotice' ), 10 );
		add_action( 'rex_checkoutify_loaded_admin', array( $this, 'rex_checkoutify_loaded_admin' ), 10 );
	}


	/**
	 * Hide Notices on Checkoutify Pages
	 *
	 * This method removes all admin notices from Checkoutify pages.
	 *
	 * @return void
	 *
	 * @since 1.0.0
	 */
	public function hideNotice() {
		global $current_screen;

		$selectdPages = array(
			'woocommerce_page_checkoutify',
		);
		
		// Check if the current screen is in selected pages for Checkoutify.
		if ( in_array( $current_screen->base, $selectdPages, true ) ) {
			
			// Remove all actions hooked to 'admin_notices' to hide notices.
			remove_all_actions( 'admin_notices' );
		}
	}


	/**
	 * Load Rex 
	 */
	public function rex_checkoutify_loaded_admin($object) {
		if ( class_exists( '\RexTheme\Checkoutify\Rest\Actions\RexLicenseManager' )  && defined('CHECKOUTIFY_AUTHOR_REX') ) {
			$license_key = trim( get_option( Keys::CHECKOUTIFY_LICENSE_KEY ) );
			if ( !empty( $license_key ) ) {
				$object->container[ 'software_licensing' ] = new \RexTheme\Checkoutify\Admin\RexCheckoutifyPluginUpdater(
					REX_CHECKOUTIFY_SL_STORE_URL,
					__FILE__,
					[
						'version' => CHECKOUTIFY_VERSION,
						'license' => $license_key,
						'item_id' => REX_CHECKOUTIFY_ITEM_ID,
						'author'  => 'RexTheme',
						'beta'    => false
					]
				);
			}
		}
	}
}
