<?php
/**
 * File containing the Menu class for the RexTheme Checkoutify plugin.
 *
 * This file defines the Menu class, which handles the WordPress admin menu and submenu creation for the plugin.
 *
 * @since 1.0.0
 * @package RexTheme\Checkoutify\Admin
 */

namespace RexTheme\Checkoutify\Admin;

use RexTheme\Checkoutify\Assets\LoadAssets;

/**
 * Class Menu
 *
 * This class handles the admin menu and pages for the RexTheme Checkoutify plugin.
 *
 * @since 1.0.0
 */
class Menu {

	/**
	 * Admin constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'init_menu' ) );
	}


	/**
	 * Init menu
	 *
	 * @since 1.0.0
	 */
	public function init_menu() {
		global $submenu;

		$slug          = CHECKOUTIFY_SLUG;
		$menu_position = 57;
		$capability    = 'manage_options';
		$parent_slug   = 'woocommerce'; 

		add_submenu_page(
			$parent_slug,
			esc_attr__('Checkoutify', 'checkoutify'),
			esc_attr__('Checkoutify', 'checkoutify'),
			$capability,
			$slug,
			array($this, 'plugin_page'),
			$menu_position
		);
	}


	/**
	 * Render the plugin page.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function plugin_page() {
		$assets = new LoadAssets();
		$assets->admin();
		require_once CHECKOUTIFY_TEMPLATE_PATH . '/app.php';
	}
}
