<?php
/**
 * Manage all key strings for the RexTheme Checkoutify plugin.
 *
 * This file defines various constant keys used within the plugin for settings, options, and metadata.
 *
 * @since 1.0.0
 * @package RexTheme\Checkoutify\Common
 */

namespace RexTheme\Checkoutify\Common;

/**
 * Manage all key strings.
 *
 * @since 1.0.0
 */
class Keys {

	/**
	 * Plugin installed option key.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_INSTALLED = 'checkoutify_installed';

	/**
	 * Plugin version key.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_VERSION = 'checkoutify_version';

	/**
	 * Plugin seeder ran key.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_SEEDER_RAN = 'checkoutify_type_seeder_ran';

	/**
	 * Plugin ran key.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_RAN = 'checkoutify_job_seeder_ran';

	/**
	 * Checkout meta key for saving data.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_CHECKOUT_META = 'checkoutify_checkout_data';

	/**
	 * Checkout meta key for saving data.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_CHECKOUT_SETTINGS_META = 'checkoutify_checkout_settings';

	/**
	 * Checkout option meta key for saving global settings.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_CHECKOUT_OPTION_META = 'checkoutify_global_settings';


	/**
	 * Checkout option meta key for saving global settings.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_SHORTCODE_KEY = 'checkoutify';

	/**
	 * Checkout custom fields key for saving meta data.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_CUSTOM_FIELDS_META = 'checkoutify_custom_fields';


	/**
	 * Checkout fields key for all checkout input fields.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_FIELDS = 'checkoutify_fields';

	/**
	 * Checkout orderbumo key for all checkout input fields.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_ORDERBUMP = 'checkoutify_orderbump';
	
	
	/**
	 * Checkout default fields key for all checkout input fields.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_DEFAULT_FIELDS = 'checkoutify_default_fields';


	/**
	 * License key
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_LICENSE_KEY = 'checkoutify_license_key';


	/**
	 * License data
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_LICENSE_DATA = 'checkoutify_license_data';


	/**
	 * License status
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_LICENSE_STATUS = 'checkoutify_license_status';


	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const CHECKOUTIFY_MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const CHECKOUTIFY_MINIMUM_PHP_VERSION = '7.0';


	/**
	 * Checkout option meta key for set default settings.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_DEFAULT_CHECKOUT_KEY = 'checkoutify_default_checkout_id';

	/**
	 * The option name used to store checkout information associated with funnel IDs in the WordPress options table.
	 *
	 * This constant represents the option name used to store and retrieve checkout information
	 * associated with specific funnel IDs in the WordPress options table.
	 *
	 * @var string
	 *
	 * @since 1.0.0
	 */
	const CHECKOUTIFY_FUNNEL_ID = 'checkoutify_funnel_id';

    const CHECKOUTIFY_HTML_TAGS = 'checkoutify_html_tags';

}
