<?php
/**
 * WPFunnels.php
 *
 * This file initializes the funnel class, ensuring compatibility with the Checkoutify plugin.
 *
 * @package RexTheme\Checkoutify\Compatibility
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\Compatibility;

use WPFunnels\Wpfnl_functions;
use WPFunnels\Data_Store\Wpfnl_Steps_Store_Data;
use RexTheme\Checkoutify\Common\Functions;

/**
 * Class WPFunnels
 *
 * This class manages Compatibility with WPFunnels and Checkoutify.
 *
 * @since 1.0.0
 */
class WPFunnels {


	/**
	 * WPFunnels class constructor.
	 *
	 * Initializes the class and adds necessary actions for compatibility.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		 add_action( 'wp', array( $this, 'checkoutShortcodeMetas' ) );
	}

	/**
	 * Insert helper hidden IDs.
	 *
	 * This method inserts hidden input fields with necessary IDs for compatibility.
	 *
	 * @since 1.0.0
	 */
	public function checkoutShortcodeMetas() {
		add_action( 'checkoutify_checkout_form', [$this, 'addWpfMetas']);
	}
	
	
	/**
	 * Insert helper hidden IDs.
	 *
	 * This method inserts hidden input fields with necessary IDs for compatibility.
	 *
	 * @since 1.0.0
	 */
	public function addWpfMetas() {
		if ( Wpfnl_functions::check_if_this_is_step_type( 'checkout' ) ) {
			global $post;
			$step_id = $post->ID;
			$step    = new Wpfnl_Steps_Store_Data();
			$step->read( $step_id );
			$funnel_id = $step->get_funnel_id();
			do_action( 'wpfunnels/before_checkout_form', get_the_ID() );
			echo '<input type="hidden" class="input-hidden _wpfunnels_funnel_id" name="_wpfunnels_funnel_id" value="' . intval( $funnel_id ) . '">';
			echo '<input type="hidden" class="input-hidden _wpfunnels_checkout_id" name="_wpfunnels_checkout_id" value="' . intval( $post->ID ) . '">'; //phpcs:ignore
			echo '<input type="hidden" class="input-hidden _wpfunnels_order_unique_identifier" name="_wpfunnels_order_unique_identifier" value="' . uniqid() . '">';
		}
	}


}
