<?php
/**
 * Class Register
 *
 * This class manages the registration of custom post types related to checkouts in the WordPress admin panel for Checkoutify.
 *
 * @since 1.0.0
 * @package YourPackageName
 */

namespace RexTheme\Checkoutify\CPT;

/**
 * Class Register
 *
 * This class manages the registration of custom post types related to checkouts in the WordPress admin panel for Checkoutify.
 *
 * @since 1.0.0
 */
class Register {


	/**
	 * Checkout constructor.
	 *
	 * Initializes a new instance of the Register class and hooks into the WordPress 'init' action to register custom post types.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'registerCheckoutifyCPT' ) );
	}


	/**
	 * Register Checkoutify Custom Post Types
	 *
	 * This method is responsible for registering custom post types related to Checkoutify.
	 *
	 * @since 1.0.0
	 */
	public function registerCheckoutifyCPT() {
		$labels = array(
			'name'          => _x( 'Checkouts', 'Checkouts general name', 'checkoutify' ),
			'singular_name' => _x( 'Checkout', 'Checkout singular name', 'checkoutify' ),
			'edit_item'     => __( 'Edit Checkout', 'checkoutify' ),
		);
		$args   = array(
			'labels'              => $labels,
			'public'              => true,
			'query_var'           => true,
			'can_export'          => true,
			'exclude_from_search' => true,
			'show_ui'             => true,
			'show_in_menu'        => false,
			'show_in_admin_bar'   => false,
			'show_in_rest'        => true,
			'supports'            => array( 'title', 'editor', 'elementor', 'revisions', 'thumbnail', 'custom-fields' ),
			'capability_type'     => 'post',
			'map_meta_cap'        => true,
		);

		if ( isset( $_GET['ct_builder'] ) && 'true' === $_GET['ct_builder'] ) { //phpcs:ignore 
			$args['show_in_admin_bar'] = true;
		}
		$args['rewrite'] = array(
			'slug'       => 'checkoutify',
			'with_front' => false,
		);
		register_post_type( CHECKOUTIFY_POST_TYPE, $args );
	}
}
