<?php
/**
 * CustomField.php
 *
 * Manages custom fields in the checkout module.
 *
 * @package RexTheme\Checkoutify\Module\Field
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\Module\Field;

use RexTheme\Checkoutify\Common\Keys;
use RexTheme\Checkoutify\Common\Functions;
use RexTheme\Checkoutify\Abstracts\Fields;
/**
 * Class CustomField
 *
 * Manages custom fields in the checkout module.
 *
 * @package RexTheme\Checkoutify\Module\Field
 * @since 1.0.0
 */
class CustomField{

    /**
     * Fields array.
     *
     * @var array
     */
    public $fields = [];

    /**
     * Checkout ID.
     *
     * @var null
     */
    public $checkoutId = null;

    /**
     * CustomField constructor.
     *
     * @param null $checkoutId
     * @since 1.0.0
     */
    public function __construct($checkoutId) {
        $this->checkoutId = $checkoutId;
    }

    /**
     * Get fields.
     *
     * @return array
     * @since 1.0.0
     */
    public function getFields() {
        $this->fields = get_post_meta($this->checkoutId, Keys::CHECKOUTIFY_FIELDS, true);
        return $this->fields;
    }

    /**
     * Get styles for supported styles.
     *
     * @param array $supportedStyles
     * @return array
     * @since 1.0.0
     */
    public function getStyles($supportedStyles = []) {
        $styles = [];
        foreach ($supportedStyles as $supportedStyle) {
            $className = "\\RexTheme\\Checkoutify\\Module\Style\\" . ucfirst($supportedStyle);
            if( class_exists($className)){
                $styleInstance = new $className();
                $styles[$supportedStyle] = $styleInstance->getProperties();
            }   
        }
        return $styles;
    }
}
