<?php
/**
 * Coupon.php
 *
 * Manages the coupon field module.
 *
 * @package RexTheme\Checkoutify\Module\Field
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\Module\Field;

use RexTheme\Checkoutify\Abstracts\AdvancedFields;
/**
 * Class Coupon
 *
 * Manages the coupon field module.
 *
 * @package RexTheme\Checkoutify\Module\Field
 * @since 1.0.0
 */
class Coupon extends AdvancedFields {

    /**
     * CSS properties
     *
     * @var array
     */
    public $properties;

    /**
     * Supported styles
     *
     * @var array
     */
    public $supportedStyles;

    /**
     * Coupon constructor.
     *
     * Initializes properties and supported styles.
     *
     * @since 1.0.0
     */
    public function __construct() {
        $this->properties = array(
            'key'                => 'coupon',
            'fieldType'          => 'coupon',
            'class'              => array('rex-checkoutify-coupon'),
            'label'              => __('Coupon', 'checkoutify'),
            'name'               => 'coupon',
            'fieldCategory'      => 'wooField',
        );

        $this->supportedStyles = ['label','input','button'];
    }

    /**
     * Get the field properties.
     *
     * @return array
     * @since 1.0.0
     */
    public function getField() {
        $styles = $this->getStyles($this->supportedStyles);
        $properties = $this->properties;
        $properties['styles']['coupon'] = $styles;
        return $properties;
    }
}
