<?php
/**
 * OrderDetails.php
 *
 * Manages the order details field module.
 *
 * @package RexTheme\Checkoutify\Module\Field
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\Module\Field;

use RexTheme\Checkoutify\Abstracts\AdvancedFields;
/**
 * Class OrderDetails
 *
 * Manages the order details field module.
 *
 * @package RexTheme\Checkoutify\Module\Field
 * @since 1.0.0
 */
class OrderDetails extends AdvancedFields {

    /**
     * CSS properties
     *
     * @var array
     */
    public $properties;

    /**
     * Supported styles
     *
     * @var array
     */
    public $supportedStyles;

    /**
     * OrderDetails constructor.
     *
     * Initializes properties and supported styles.
     *
     * @since 1.0.0
     */
    public function __construct() {
        $this->properties = array(
            'key'                => 'order_details',
            'fieldType'          => 'order-details',
            'class'              => array('rex-checkoutify-order-details'),
            'label'              => __('Order Details', 'checkoutify'),
            'name'               => 'order_details',
            'fieldCategory'      => 'wooField',
        );
        $this->supportedStyles = ['product','subTotal','shipping','total'];
    }

    /**
     * Get the field properties.
     *
     * @return array
     * @since 1.0.0
     */
    public function getField() {
        $styles = $this->getStyles($this->supportedStyles);
        $properties = $this->properties;
        $properties['styles']['orderDetails'] = $styles;
        return $properties;
    }
}
