<?php
/**
 * Api.php
 *
 * This file defines the Api class, which serves as an API manager for the RexTheme Checkoutify plugin. It's responsible for registering all API classes and initializing REST API routes.
 *
 * @package RexTheme\Checkoutify\REST
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\REST;

/**
 * API Manager class.
 *
 * All API classes would be registered here.
 *
 * @since 1.0.0
 */
class Api {

	/**
	 * Class dir and class name mapping.
	 *
	 * @var array
	 *
	 * @since 1.0.0
	 */
	protected $class_map;

	/**
	 * Constructor.
	 */
	public function __construct() {
		if ( ! class_exists( 'WP_REST_Server' ) ) {
			return;
		}

		$this->class_map = apply_filters(
			'checkoutify_rest_api_class_map',
			array(
				\RexTheme\Checkoutify\REST\CheckoutController::class,
				\RexTheme\Checkoutify\REST\LayoutController::class,
				\RexTheme\Checkoutify\REST\LicenseController::class,
				\RexTheme\Checkoutify\REST\OrderbumpController::class,
                \RexTheme\Checkoutify\REST\ContactController::class,
			)
		);

		// Init REST API routes.
		add_action( 'rest_api_init', array( $this, 'registerRestRoutes' ), 10 );
	}


	/**
	 * Register REST API routes.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function registerRestRoutes(): void {
		foreach ( $this->class_map as $controller ) {
			$this->$controller = new $controller();
			$this->$controller->registerRoutes();
		}
	}
}
