<?php
/**
 * ContactManager Class
 *
 * This file contains the ContactManager class which handles the creation of contacts
 * and sending them to MailMint via webhook.
 *
 * @package RexTheme\Checkoutify\Rest\Actions
 * @since 1.0.3
 */

namespace RexTheme\Checkoutify\Rest\Actions;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/**
 * Class ContactManager
 *
 * This class handles the creation of contacts and sending them to MailMint via webhook.
 *
 * @package RexTheme\Checkoutify\Rest\Actions
 * @since 1.0.3
 */
class ContactManager {

    protected $webHookUrl = [CHECKOUTIFY_WEBHOOK_URL];

    /**
     * Email
     *
     * @var string
     * @since 1.0.3
     */
    protected $email = '';

    /**
     * Name
     *
     * @var string
     * @since 1.0.3
     */
    protected $name = '';

    /**
     * Constructor
     *
     * @param string $email
     * @param string $name
     * @since 1.0.3
     */
    public function __construct( $email, $name ) {
        $this->email = $email;
        $this->name  = $name;
    }


    /**
     * Create contact to MailMint via webhook
     *
     * @return array
     * @since 1.0.3
     */
    public function create_contact_via_webhook(){

        if( !$this->email ){
            return [
                'success' => false,
            ];
        }

        $response = [
            'success' => true,
        ];

        $json_body_data = json_encode([
            'email'         => $this->email,
            'first_name'    => $this->name,
        ]);

        try{
            if( !empty($this->webHookUrl ) ){
                foreach( $this->webHookUrl as $url ){
                    $response = wp_remote_request($url, [
                        'method'    => 'POST',
                        'headers' => [
                            'Content-Type' => 'application/json',
                        ],
                        'body' => $json_body_data
                    ]);
                }
            }
        } catch(\Exception $e){
            error_log($e->getMessage());
            $response = [
                'success' => false,
            ];
        }

        return $response;
    }
}
