<?php
/**
 * Checkout Controller
 *
 * @package RexTheme\Checkoutify\REST
 * @version 1.0.0
 * @author A S M Nasim
 */

namespace RexTheme\Checkoutify\REST;

use RexTheme\Checkoutify\Abstracts\RESTController;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WP_Error;
use \RexTheme\Checkoutify\Module\Checkout;
use RexTheme\Checkoutify\Common\Functions;
use RexTheme\Checkoutify\Common\Keys;
/**
 * API CheckoutController class.
 *
 * @since 0.3.0
 */
class CheckoutController extends RESTController {

	/**
	 * Route base.
	 *
	 * @var string
	 */
	protected $base = 'checkout';

	/**
	 * Register all routes related with carts.
	 *
	 * @return void
	 */
	public function registerRoutes() {
		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/get',
			array(
				array(
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => array( $this, 'getCheckouts' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => $this->getCollectionParams(),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/get/single/(?P<id>\d+)',
			array(
				array(
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => array( $this, 'getSingleCheckout' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'id' => array(
							'description' => __( 'Checkout ID.', 'checkoutify' ),
							'type'        => 'integer',
							'required'    => true,
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/update/(?P<id>\d+)',
			array(
				array(
					'methods'             => WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'updateCheckout' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'id' => array(
							'description' => __( 'Checkout ID.', 'checkoutify' ),
							'type'        => 'integer',
							'required'    => true,
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/create',
			array(
				array(
					'methods'             => WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'createCheckout' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'data'            => array(
							'title' => array(
								'description' => __( 'Checkout title.', 'checkoutify' ),
								'type'        => 'string',
								'required'    => true,
							),
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/import',
			array(
				array(
					'methods'             => WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'importCheckout' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);
		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/duplicate/(?P<id>\d+)',
			array(
				array(
					'methods'             => WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'duplicateCheckout' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/status',
			array(
				array(
					'methods'             => WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'updateStatus' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'id'     => array(
							'description' => __( 'Checkout ID.', 'checkoutify' ),
							'type'        => 'integer',
							'required'    => true,
						),
						'status' => array(
							'description' => __( 'Checkout status.', 'checkoutify' ),
							'type'        => 'string',
							'required'    => true,
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/delete',
			array(
				array(
					'methods'             => WP_REST_Server::DELETABLE,
					'callback'            => array( $this, 'deleteCheckout' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'id' => array(
							'description' => __( 'Checkout ID.', 'checkoutify' ),
							'type'        => 'integer',
							'required'    => true,
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/multiple-delete',
			array(
				array(
					'methods'             => WP_REST_Server::DELETABLE,
					'callback'            => array( $this, 'deleteMultipleCheckouts' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'ids' => array(
							'type'     => 'string',
							'required' => true,
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/create-field',
			array(
				array(
					'methods'             => WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'createOrUpdateCheckoutInputField' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'data'            => array (
							'label' => array(
								'description' => __( 'Checkout label.', 'checkoutify' ),
								'type'        => 'string',
								'required'    => true,
							),
							'name' => array(
								'description' => __( 'Checkout name.', 'checkoutify' ),
								'type'        => 'string',
								'required'    => true,
							),
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);

		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/update-title',
			array(
				array(
					'methods'             => WP_REST_Server::EDITABLE,
					'callback'            => array( $this, 'updateCheckoutTitle' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => array(
						'data'            => array(
							'title' => array(
								'description' => __( 'Checkout title.', 'checkoutify' ),
								'type'        => 'string',
								'required'    => true,
							),
							'id' => array(
								'description' => __( 'Checkout id.', 'checkoutify' ),
								'type'        => 'integer',
								'required'    => true,
							),
						),
					),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);


		register_rest_route(
            $this->namespace, '/' . $this->base . '/get/checkout/fields/(?P<id>\d+)',
            [
                [
                    'methods'             => WP_REST_Server::READABLE,
                    'callback'            => [ $this, 'getCheckoutFields' ],
                    'permission_callback' => [ $this, 'checkPermission' ],
					'args'                => $this->getCollectionParams(),
                    'schema'              => [ $this, 'getItemSchema' ],
                ],
            ]
        );


		register_rest_route(
            $this->namespace, '/' . $this->base . '/get/checkout-fields',
            [
                [
                    'methods'             => WP_REST_Server::READABLE,
                    'callback'            => [ $this, 'getCheckoutFields' ],
                    'permission_callback' => [ $this, 'checkPermission' ],
                    'args'                => $this->getCollectionParams(),
                    'schema'              => [ $this, 'getItemSchema' ],
                ],
            ]
        );

		register_rest_route(
            $this->namespace,
            '/' . $this->base . '/delete/custom-field',
            array(
                array(
                    'methods'             => WP_REST_Server::EDITABLE,
                    'callback'            => array( $this, 'deleteCustomField' ),
                    'permission_callback' => array( $this, 'checkPermission' ),
                    'args'                => array(
                        'data'            => array(
                            'index' => array(
                                'description' => __( 'Custom field index.', 'checkoutify' ),
                                'type'        => 'integer',
                                'required'    => true,
                            ),
                            'checkoutId' => array(
                                'description' => __( 'Checkout ID.', 'checkoutify' ),
                                'type'        => 'integer',
                                'required'    => true,
                            ),
                        ),
                    ),
                    'schema'              => array( $this, 'getItemSchema' ),
                ),
            )
        );

        register_rest_route(
            $this->namespace,
            '/' . $this->base . '/create-heading-field',
            array(
                array(
                    'methods'             => WP_REST_Server::EDITABLE,
                    'callback'            => array( $this, 'createOrUpdateCheckoutHeadingField' ),
                    'permission_callback' => array( $this, 'checkPermission' ),
                    'args'                => array(
                        'data'            => array (
                            'label' => array(
                                'description' => __( 'Checkout label.', 'checkoutify' ),
                                'type'        => 'string',
                                'required'    => true,
                            ),
                            'name' => array(
                                'description' => __( 'Checkout name.', 'checkoutify' ),
                                'type'        => 'string',
                                'required'    => true,
                            ),
                        ),
                    ),
                    'schema'              => array( $this, 'getItemSchema' ),
                ),
            )
        );

        register_rest_route(
            $this->namespace,
            '/' . $this->base . '/delete-html-tags',
            array(
                array(
                    'methods'             => WP_REST_Server::EDITABLE,
                    'callback'            => array( $this, 'deleteHtmlTags' ),
                    'permission_callback' => array( $this, 'checkPermission' ),
                    'args'                => array(
                        'id' => array(
                            'type'        => 'string',
                            'required'    => true,
                            'sanitize_callback' => function ( $param ) {
                                return sanitize_text_field( $param );
                            },
                        ),
                        'index' => array(
                            'type'        => 'string',
                            'required'    => true,
                            'sanitize_callback' => function ( $param ) {
                                return sanitize_text_field( $param );
                            },
                        ),
                    ),
                    'schema'              => array( $this, 'getItemSchema' ),
                ),
            )
        );

	}


	/**
	 * Retrieves a collection of checkout items.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function getCheckouts( $request ): ?WP_REST_Response {
        $status = !empty( $request->get_param('status') ) ? $request->get_param('status') : '';
		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->getCheckouts(-1, $status);
		$response['maybeLicenseActivate'] = Functions::maybeLicenseActivate();
		return rest_ensure_response( $response );
	}
	
	/**
	 * Retrieves a collection of checkout items.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function getSingleCheckout( $request ): ?WP_REST_Response {
		$required_params = array( 'id' );
		foreach ( $required_params as $param ) {
			if ( ! $request->has_param( $param ) ) {
				return rest_ensure_response(
					$this->prepareWpErrorResponse(
						__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
						400
					)
				);
			}
		}
		$id               = sanitize_text_field( $request['id'] );
		$checkoutInstance = new Checkout();
		$maybeDeatultCheckout = $checkoutInstance->maybeDeatultCheckout( $id );
		$response         = $checkoutInstance->getSingleCheckout( $id );
		$response['maybeDeatultCheckout'] = $maybeDeatultCheckout;
		return rest_ensure_response( $response );
	}


	/**
	 * Retrieves a collection of checkout items.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function createCheckout( $request ): ?WP_REST_Response {
		$required_params = array( 'title' );

		if($request->has_param('data')){
			foreach ( $required_params as $param ) {
				if ( !array_key_exists( $param, $request['data'] ) ) {
					return rest_ensure_response(
						$this->prepareWpErrorResponse(
							__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
							400
						)
					);
				}
			}
		} else {
			return rest_ensure_response(
				$this->prepareWpErrorResponse(
					__( "Required parameter data is missing.", 'checkoutify' ), //phpcs:ignoreFile
					400
				)
			);
		}

		$data             = array(
			'title' => sanitize_text_field( $request['data']['title'] ),
		);
		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->create( $data );
		return rest_ensure_response( $response );
	}
	
	
	/**
	 * Retrieves a collection of checkout items.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function importCheckout( $request ): ?WP_REST_Response {
		$required_params = array( 'layout' );
		if($request->has_param('data')){
			foreach ( $required_params as $param ) {
				if ( !array_key_exists( $param, $request['data'] ) ) {
					return rest_ensure_response(
						$this->prepareWpErrorResponse(
							__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
							400
						)
					);
				}
			}
		} else {
			return rest_ensure_response(
				$this->prepareWpErrorResponse(
					__( "Required parameter data is missing.", 'checkoutify' ), //phpcs:ignoreFile
					400
				)
			);
		}

		$data             = array(
			'layout' => $request['data']['layout'],
		);

		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->import( $data );
		return rest_ensure_response( $response );
	}
	
	/**
	 * Duplicate a checkout item.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function duplicateCheckout( $request ): ?WP_REST_Response {
		$required_params = array( 'id' );
		foreach ( $required_params as $param ) {
			if ( ! $request->has_param( $param ) ) {
				return rest_ensure_response(
					$this->prepareWpErrorResponse(
						__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
						400
					)
				);
			}
		}
		$id               = sanitize_text_field( $request['id'] );
		$checkoutInstance = new Checkout();
		$checkoutData = $checkoutInstance->getSingleCheckout($id);
		$checkoutStatus = get_post_status( $id );
		
		$payload = array(
			'layout' => isset($checkoutData['metas']) ? $checkoutData['metas'] : '',
			'duplicate' => 'yes',
			'status'    => isset( $checkoutStatus ) && !empty( $checkoutStatus ) ? $checkoutStatus : 'publish'
		);
		$checkoutInstance->import( $payload );
		$response         = $checkoutInstance->getCheckouts();
		return rest_ensure_response( $response );
	}


	/**
	 * Retrieves a collection of checkout items.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function updateCheckout( $request ): ?WP_REST_Response {
		$required_params = array( 'id', 'status','maybeDefaultCheckout' );
		foreach ( $required_params as $param ) {
			if ( ! $request->has_param( $param ) ) {
				return rest_ensure_response(
					$this->prepareWpErrorResponse(
						__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
						400
					)
				);
			}
		}
		$id              	  = sanitize_text_field( $request['id'] );
		$status           	  = sanitize_text_field( $request['status'] );
		$maybeDefaultCheckout = sanitize_text_field( $request['maybeDefaultCheckout'] );
		$funnelId             = sanitize_text_field( $request['funnelId']);
		$data                 = isset( $request['data'] ) ? $request['data'] : array();
		$checkoutInstance     = new Checkout();
		$payload = [
			'id' => $id,
			'status' => $status,
		];
		
		$response         = $checkoutInstance->setDeatultCheckout( $id, $maybeDefaultCheckout );
		$response         = $checkoutInstance->updateStatus( $payload );
		$response 		  = $checkoutInstance->setFunnelCheckout( $funnelId, $id );
		$response         = $checkoutInstance->updateSingleCheckout( $id, $data );
		return rest_ensure_response( $response );
	}


	/**
	 * Delete a checkout item based on the provided ID.
	 *
	 * This method is used to delete a checkout item using the WordPress REST API.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request, including the ID to delete.
	 *
	 * @return WP_REST_Response|null Response object on success, or null on failure.
	 */
	public function deleteCheckout( $request ): ?WP_REST_Response {
		$required_params = array( 'id' );
		foreach ( $required_params as $param ) {
			if ( ! $request->has_param( $param ) ) {
				return rest_ensure_response(
					$this->prepareWpErrorResponse(
						__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
						400
					)
				);
			}
		}

		$id               = sanitize_text_field( $request['id'] );
		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->delete( $id );
		return rest_ensure_response( $response );
	}

	/**
	 * Delete multiple checkouts based on the provided IDs.
	 *
	 * This method handles a REST API request to delete multiple checkouts identified by the given IDs.
	 *
	 * @param WP_REST_Request $request The REST API request object.
	 * @return WP_REST_Response A response object with the result of the deletion operation. It can include success or error information.
	 *
	 * @since 1.0.0
	 */
	public function deleteMultipleCheckouts( $request ) {
		$required_params = array( 'ids' );
		foreach ( $required_params as $param ) {
			if ( ! $request->has_param( $param ) ) {
				return rest_ensure_response(
					$this->prepareWpErrorResponse(
						__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
						400
					)
				);
			}
		}

		$requested_ids = isset( $request['ids'] ) ? $request['ids'] : '';
		$ids           = explode( ',', $requested_ids );

		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->deleteMultipleCheckouts( $ids );
		return rest_ensure_response( $response );
	}


	/**
	 * Delete a checkout item based on the provided ID.
	 *
	 * This method is used to delete a checkout item using the WordPress REST API.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request, including the ID to delete.
	 *
	 * @return WP_REST_Response|null Response object on success, or null on failure.
	 */
	public function updateStatus( $request ): ?WP_REST_Response {
		$required_params = array( 'id', 'status' );
		foreach ( $required_params as $param ) {
			if ( ! $request->has_param( $param ) ) {
				return rest_ensure_response(
					$this->prepareWpErrorResponse(
						__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
						400
					)
				);
			}
		}

		$payload          = array(
			'id'     => sanitize_text_field( $request['id'] ),
			'status' => sanitize_text_field( $request['status'] ),
		);
		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->updateStatus( $payload );
		return rest_ensure_response( $response );
	}



	/**
	 * Retrieves the group schema, conforming to JSON Schema.
	 *
	 * @since 1.0.0
	 * @return array
	 */
	public function getItemSchema() {
		if ( $this->schema ) {
			return $this->add_additional_fields_schema( $this->schema );
		}

		$schema = array(
			'$schema'    => 'http://json-schema.org/draft-04/schema#',
			'title'      => 'job',
			'type'       => 'object',
			'properties' => array(),
		);

		$this->schema = $schema;

		return $this->add_additional_fields_schema( $this->schema );
	}


	/**
	 * Create a new field or update a field for the checkout process.
	 *
	 * This method handles a REST API request to create a new custom field or update with the provided parameters.
	 *
	 * @param WP_REST_Request $request The REST API request object containing field data.
	 * @return WP_REST_Response|null A response object with the result of the field creation operation, or null on failure.
	 *
	 * @since 1.0.0
	 */
	public function createOrUpdateCheckoutInputField( $request ) : ?WP_REST_Response {
		
		$required_params = array( 'label', 'name' );

		if($request->has_param('data')){
			foreach ( $required_params as $param ) {
				if ( !array_key_exists($param, $request['data']) ) {
					return rest_ensure_response(
						$this->prepareWpErrorResponse(
							__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
							400
						)
					);
				}
			}
		} else {
			return rest_ensure_response(
				$this->prepareWpErrorResponse(
					__( "Required parameter data is missing.", 'checkoutify' ), //phpcs:ignoreFile
					400
				)
			);
		}

		$data = array(
			'fieldType'          => sanitize_text_field( $request['data']['fieldType'] ),
			'label'              => sanitize_text_field( $request['data']['label'] ),
			'name'               => sanitize_text_field( $request['data']['name'] ),
			'key'				 => sanitize_text_field( $request['data']['name'] ),
			'default'            => sanitize_text_field( $request['data']['default'] ),
			'placeholder'        => sanitize_text_field( $request['data']['placeholder'] ),
			'showInOrderPage'    => filter_var( $request['data']['showInOrderPage'], FILTER_VALIDATE_BOOLEAN ),
			'showOnThankYouPage' => filter_var( $request['data']['showOnThankYouPage'], FILTER_VALIDATE_BOOLEAN ),
			'showInEmail'        => filter_var( $request['data']['showInEmail'], FILTER_VALIDATE_BOOLEAN ),
			'validation'         => sanitize_text_field( $request['data']['validation'] ),
			'required'           => filter_var( $request['data']['required'], FILTER_VALIDATE_BOOLEAN ),
			'checkoutId'         => sanitize_text_field( $request['data']['checkoutId'] ),
			'options'            => is_array( $request['data']['options'] ) ? $request['data']['options'] : array(),
			'section'            => sanitize_text_field( $request['data']['section']),
			'fieldCategory'      => sanitize_text_field( $request['data']['fieldCategory']),
		);

        if('date' === $data['fieldType']){
            $data['startDate'] = sanitize_text_field($request['data']['startDate']);
            $data['endDate'] = sanitize_text_field($request['data']['endDate']);
        }

        if('time' === $data['fieldType']){
            $data['startTime'] = sanitize_text_field($request['data']['startTime']);
            $data['endTime'] = sanitize_text_field($request['data']['endTime']);
        }

        if('file' === $data['fieldType']){
            $data['maxFileSize'] = sanitize_text_field($request['data']['maxFileSize']);
        }

		if(isset($request['data']['operationType']) && 'edit' === $request['data']['operationType']){
			$data['operationType'] = sanitize_text_field($request['data']['operationType']);
			$data['index'] = sanitize_text_field($request['data']['index']);
			$data['fieldVariation'] = sanitize_text_field($request['data']['fieldVariation']);
		}
		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->createOrUpdateCheckoutField( $data );

		return rest_ensure_response( $response );
	}

	/**
	 * Update the title of a checkout using a REST API request.
	 *
	 * This function is used to update the title of a checkout using a REST API request. It expects the 'title' and 'id' parameters in the request data.
	 *
	 * @param WP_REST_Request $request The REST API request object.
	 *
	 * @return WP_REST_Response|null The response object containing the result of the update operation. If the required parameters are missing, it returns a 400 Bad Request response. If the update is successful, it returns a response with a success message. If there is an error during the update, it returns an error response.
	 * 
	 * @since 1.0.0
	 */
	public function updateCheckoutTitle($request) : ?WP_REST_Response {
		$required_params = array('title', 'id');

		if($request->has_param('data')){
			foreach ( $required_params as $param ) {
				if ( ! array_key_exists( $param, $request['data'] ) ) {
					return rest_ensure_response(
						$this->prepareWpErrorResponse(
							__( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
							400
						)
					);
				}
			}
		} else {
			return rest_ensure_response(
				$this->prepareWpErrorResponse(
					__( "Required parameter data is missing.", 'checkoutify' ), //phpcs:ignoreFile
					400
				)
			);
		}

		$data = array(
			'title'          => sanitize_text_field( $request['data']['title'] ),
			'id' 			 => sanitize_text_field( $request['data']['id'] )
		);
		
		
		$checkoutInstance = new Checkout();
		$response         = $checkoutInstance->updateCheckoutTitleField( $data );
		return rest_ensure_response( $response );
	}

	/**
	 * Retrieve custom fields for a checkout.
	 *
	 * This endpoint retrieves custom fields associated with a checkout by its ID. It ensures that all required parameters are provided in the request and returns the custom fields data if the checkout is found.
	 *
	 * @param WP_REST_Request $request The REST request object.
	 *
	 * @return WP_REST_Response A REST response containing the custom fields data if successful, or an error response if any required parameters are missing or if the checkout is not found.
	 *
	 * @since 1.0.0
	 */
	public function getCheckoutFields( $request ): ?WP_REST_Response {
		
        $required_params = array( 'id' );
		foreach ( $required_params as $param ) {
			if ( ! $request->has_param( $param ) ) {
				return rest_ensure_response( $this->prepareWpErrorResponse(
					__( "Required parameter '$param' is missing.", 'checkoutify' ), 400
				) );
			}
		}
        $id = sanitize_text_field( $request['id'] );
        $checkoutInstance = new Checkout();
        $response  = $checkoutInstance->getCheckoutFieldsData($id);
		
        return rest_ensure_response( $response );
    }

	/**
	 * Delete a custom checkout field based on the provided request parameters.
	 *
	 * This REST API endpoint allows the deletion of a custom checkout field specified by
	 * the 'index' and 'checkoutId' parameters in the request data.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request The REST API request object.
	 * @return WP_REST_Response|null Returns a REST API response indicating the result of the operation,
	 *                              or null if there's an issue with the required parameters.
	 */
	public function deleteCustomField( $request ): ?WP_REST_Response {
        $required_params = array( 'index', 'checkoutId' );
        if($request->has_param('data')){
            foreach ( $required_params as $param ) {
                if ( ! array_key_exists( $param, $request['data'] ) ) {
                    return rest_ensure_response(
                        $this->prepareWpErrorResponse(
                            __( "Required parameter '$param' is missing.", 'checkoutify' ), //phpcs:ignoreFile
                            400
                        )
                    );
                }
            }
        } else {
            return rest_ensure_response(
                $this->prepareWpErrorResponse(
                    __( "Required parameter data is missing.", 'checkoutify' ), //phpcs:ignoreFile
                    400
                )
            );
        }
        $index = sanitize_text_field( $request['data']['index'] );
        $checkoutId = sanitize_text_field( $request['data']['checkoutId'] );
        $data = array(
            'index' => $index,
            'checkoutId' => $checkoutId
        );
        $checkoutInstance = new Checkout();
        $response  = $checkoutInstance->deleteCustomCheckoutField($data);
        return rest_ensure_response( $response );
    }

    /**
     * Create a new field or update a field for the checkout process.
     *
     * This method handles a REST API request to create a new custom field or update with the provided parameters.
     *
     * @param WP_REST_Request $request The REST API request object containing field data.
     * @return WP_REST_Response|null A response object with the result of the field creation operation, or null on failure.
     *
     * @since 1.0.7
     */
    public function createOrUpdateCheckoutHeadingField( $request ) : ?WP_REST_Response {
        $data    = !empty( $request->get_param('data') ) ? $request->get_param('data') : [];
        $label_value   = !empty( $data['label'] ) ? explode(' ', ($data['label'])) : [];
		if( !isset( $data['index'] )){
			$data['key']    = strtolower(implode('_', $label_value)).'_'. time();
			$data['name']   = strtolower(implode('_', $label_value)).'_'. time();
		}
        $checkoutInstance = new Checkout();
        $response = $checkoutInstance->createOrUpdateCheckoutHeadingField( $data );
        return rest_ensure_response( $response );
    }

    /**
     * Delete a custom checkout field based on the provided request parameters.
     *
     * This REST API endpoint allows the deletion of a custom checkout field specified by
     * the 'index' and 'checkoutId' parameters in the request data.
     *
     * @since 1.0.7
     *
     * @param WP_REST_Request $request The REST API request object.
     * @return WP_REST_Response|null Returns a REST API response indicating the result of the operation,
     *                              or null if there's an issue with the required parameters.
     */
    public function deleteHTMLTags(\WP_REST_Request $request ): ?WP_REST_Response {
        $checkoutId    = $request->get_param('id');
        $index    = $request->get_param('index');
        $checkoutInstance = new Checkout();
        $response = $checkoutInstance->deleteHTMLTags( $checkoutId, $index);
        return rest_ensure_response( $response );
    }


}
