<?php
/**
 * Contact Controller
 *
 * @package RexTheme\Checkoutify\REST
 * @version 1.0.3
 * @author RexTheme
 */

namespace RexTheme\Checkoutify\REST;

use RexTheme\Checkoutify\Abstracts\RESTController;
use RexTheme\Checkoutify\Common\Keys;
use RexTheme\Checkoutify\Rest\Actions\ContactManager;
use WP_REST_Response;
use WP_REST_Server;

/**
 * Contact Controller class.
 *
 * @since 0.3.0
 */
class ContactController extends RESTController {

    /**
     * Route base.
     *
     * @var string
     */
    protected $base = 'create-contact';


    /**
     * Register all routes related create contact.
     *
     * @throws \Exception
     * @since 1.0.3
     */
    public function registerRoutes() {

        register_rest_route(
            $this->namespace,
            '/' . $this->base,
            array(
                array(
                    'methods'             => WP_REST_Server::EDITABLE,
                    'callback'            => array( $this, 'create_contact' ),
                    'permission_callback' => array( $this, 'checkPermission' ),
                    'args'                => array(
                        'email' => array(
                            'type'        => 'string',
                            'required'    => true,
                            'sanitize_callback' => function ( $param ) {
                                return sanitize_text_field( $param );
                            },
                        ),
                    ),
                    'schema'              => array( $this, 'getItemSchema' ),
                ),
            )
        );
    }

    /**
     * Create a contact via webhook.
     *
     * This function retrieves the email and name parameters from the request,
     * creates a new instance of ContactManager, and sends the contact data
     * to the webhook.
     *
     * @since 1.0.3
     * @return WP_REST_Response The response from the ContactManager.
     */
    public function create_contact( $request ): ?WP_REST_Response{
        $email = filter_var($request->get_param('email'), FILTER_SANITIZE_EMAIL);
        $name = sanitize_text_field($request->get_param('name'));
        $contact_manager = new ContactManager($email, $name);
        $response = $contact_manager->create_contact_via_webhook( );
        return rest_ensure_response( $response );
    }
}
