<?php
/**
 * Layout Controller
 *
 * @package RexTheme\Checkoutify\REST
 * @version 1.0.0
 * @author A S M Nasim
 */

namespace RexTheme\Checkoutify\REST;

use RexTheme\Checkoutify\Abstracts\RESTController;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WP_Error;
use \RexTheme\Checkoutify\Module\Layout;

/**
 * API layoutController class.
 *
 * @since 0.3.0
 */
class LayoutController extends RESTController {

	/**
	 * Route base.
	 *
	 * @var string
	 */
	protected $base = 'layout';

	/**
	 * Register all routes related with carts.
	 *
	 * @return void
	 */
	public function registerRoutes() {
		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/get',
			array(
				array(
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => array( $this, 'getLayouts' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => $this->getCollectionParams(),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);
	}


	/**
	 * Retrieves a collection of checkout items.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function getLayouts( $request ): ?WP_REST_Response {
		$layoutInstance = new Layout();
		$response       = $layoutInstance->getLayouts();
		return rest_ensure_response( $response );
	}
}
