<?php
/**
 * SettingsController.php
 *
 * This file defines the SettingsController class, which is responsible for handling REST API requests related to settings in the RexTheme Checkoutify plugin. It registers REST routes for retrieving settings and provides a basic response for the settings items.
 *
 * @package RexTheme\Checkoutify\REST
 * @since 0.3.0
 */

namespace RexTheme\Checkoutify\REST;

use RexTheme\Checkoutify\Abstracts\RESTController;
use WP_REST_Request;
use WP_REST_Response;
use WP_REST_Server;
use WP_Error;

/**
 * API JobsController class.
 *
 * @since 0.3.0
 */
class SettingsController extends RESTController {

	/**
	 * Route base.
	 *
	 * @var string
	 */
	protected $base = 'settings';

	/**
	 * Register all routes related with carts.
	 *
	 * @return void
	 */
	public function registerRoutes() {
		register_rest_route(
			$this->namespace,
			'/' . $this->base . '/',
			array(
				array(
					'methods'             => WP_REST_Server::READABLE,
					'callback'            => array( $this, 'getItems' ),
					'permission_callback' => array( $this, 'checkPermission' ),
					'args'                => $this->getCollectionParams(),
					'schema'              => array( $this, 'getItemSchema' ),
				),
			)
		);
	}

	/**
	 * Retrieves a collection of settings items.
	 *
	 * @since 1.0.0
	 *
	 * @param WP_REST_Request $request Full details about the request.
	 * @return WP_REST_Response|WP_Error Response object on success, or WP_Error object on failure.
	 */
	public function getItems( $request ): ?WP_REST_Response {
		$data     = array();
		$response = rest_ensure_response( $data );
		return $response;
	}



	/**
	 * Retrieves the group schema, conforming to JSON Schema.
	 *
	 * @since 0.3.0
	 *
	 * @return array
	 */
	public function getItemSchema() {
		if ( $this->schema ) {
			return $this->add_additional_fields_schema( $this->schema );
		}

		$schema = array(
			'$schema'    => 'http://json-schema.org/draft-04/schema#',
			'title'      => 'job',
			'type'       => 'object',
			'properties' => array(),
		);

		$this->schema = $schema;

		return $this->add_additional_fields_schema( $this->schema );
	}

}
