<?php
/**
 * Installer class for the RexTheme Checkoutify plugin.
 *
 * @package RexTheme\Checkoutify\Setup
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\Setup;

use RexTheme\Checkoutify\Common\Keys;

/**
 * Installer class for the RexTheme Checkoutify plugin.
 *
 * @since 1.0.0
 */
class Installer {

	/**
	 * Run the installer.
	 *
	 * @since 1.0.0
	 */
	public function run() {
		// Update the installed version.
		$this->add_version();

		// Register and create tables.
		$this->register_table_names();
		$this->create_tables();
	}


	/**
	 * Add time and version on DB.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function add_version(): void {
		$installed = get_option( Keys::CHECKOUTIFY_INSTALLED );
		if ( ! $installed ) {
			update_option( Keys::CHECKOUTIFY_INSTALLED, time() );
		}
		update_option( Keys::CHECKOUTIFY_VERSION, CHECKOUTIFY_VERSION );
	}


	/**
	 * Register table names.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	private function register_table_names(): void {
		global $wpdb;

		// Register the tables to wpdb global.
		$wpdb->checkoutify = $wpdb->prefix . 'checkoutify';
	}


	/**
	 * Create necessary database tables.
	 *
	 * @since JOB_PLACE_
	 *
	 * @return void
	 */
	public function create_tables() {
		if ( ! function_exists( 'dbDelta' ) ) {
			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		}

		// Run the database table migrations.
		\RexTheme\Checkoutify\Databases\Migrations\CheckoutifyMigration::migrate();
	}
}
