<?php
/**
 * Singleton trait
 *
 * @package Rex\Checkoutify\Traits
 */

namespace RexTheme\Checkoutify\Traits;

trait Singleton {

	/**
	 * Init instance.
	 *
	 * @var object
	 * @since 1.0.0
	 */
	private static $instance;


	/**
	 * Get class instance.
	 *
	 * @return object Instance.
	 */
	public static function getInstance() {
		if ( !self::$instance ) {
			// new self() will refer to the class that uses the trait.
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Prevent cloning.
	 */
	public function __clone() {}


	/**
	 * Used to initialize the re-created object once the unserialize function has been called.
	 *
	 * @since 1.0.0
	 */
	public function __wakeup() {
		wc_doing_it_wrong( __FUNCTION__, __( 'Unserializing instances of this class is forbidden.', 'checkoutify' ), '4.6' );
		die();
	}
}
