<?php

/**
 * Checkout widget manager class
 *
 * @package RexTheme\Checkoutify\Widgets
 */

namespace RexTheme\Checkoutify\Widgets\Bricks;

require_once get_template_directory() . '/includes/elements/base.php';

use RexTheme\Checkoutify\Common\Functions;
use RexTheme\Checkoutify\Common\Keys;
use RexTheme\Checkoutify\Module\Checkout;
use \Bricks\Element;
use RexTheme\Checkoutify\Widgets\WidgetManager;
if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly



/**
 * Class CheckoutWidget
 *
 * @package RexTheme\Checkoutify\Widgets
 */
class CheckoutWidget extends Element {


    // Element properties
    public $category     = 'checkoutify'; // Use predefined element category 'general'
    public $name         = 'checkoutify'; // Make sure to prefix your elements
    public $icon         = 'fa-solid fa-cart-shopping'; // Themify icon font class
    public $css_selector = '.checkoutify-bricks-icon'; // Default CSS selector
    public $scripts      = []; // Script(s) run when element is rendered on frontend or updated in builder


     /**
     * Return localised element label
     * 
     * @return string
     * @since 1.0.0
     */
    public function get_label()
    {
        return esc_html__('Checkoutify', 'checkoutify');
    }

    
    /**
     * Set builder control groups
     * 
     * @since 1.0.0
     */
    public function set_control_groups()
    {
        $this->control_groups['checkoutify'] = [
            'title' => esc_html__('Checkoutify', 'checkoutify'), // Localized control group title
            'tab' => 'content', // Set to either "content" or "style"
        ];
    }

    /**
     * Set builder controls
     * 
     * @since 1.0.0
     */
    public function set_controls()
    {
       
        $this->controls['select_checkout'] = [
            'tab' => 'content',
            'group' => 'checkoutify',
            'label' => esc_html__('Select Checkout', 'checkoutify'),
            'type' => 'select',
            'options' => WidgetManager::getCheckouts(),
            'inline' => true,
            'clearable' => false,
            'pasteStyles' => false,
            'default' => '',
        ];
    }


    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access public
     */
    public function render()
    {
        
        $selectedCheckout = isset($this->settings['select_checkout']) ? $this->settings['select_checkout'] : '';
        ?>
        <div class="rex-checkoutify">
            <?php echo do_shortcode('[checkoutify checkout_id=' . $selectedCheckout . ']'); ?>
        </div>
        <?php

    }
}
