<?php
/**
 * Checkout widget manager class
 *
 * @package RexTheme\Checkoutify\Widgets
 */

namespace RexTheme\Checkoutify\Widgets\Elementor;

use RexTheme\Checkoutify\Common\Functions;
use RexTheme\Checkoutify\Common\Keys;
use RexTheme\Checkoutify\Module\Checkout;
use RexTheme\Checkoutify\Widgets\WidgetManager;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Controls_Stack;


if ( !defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly



/**
 * Class CheckoutWidget
 *
 * @package RexTheme\Checkoutify\Widgets
 */
class CheckoutWidget extends Widget_Base {

	/**
	 * Register the widget controls.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function init_controls() {
		if ( version_compare( ELEMENTOR_VERSION, '3.1.0', '>=' ) ) {
			$this->register_controls();
		} else {
			$this->_register_controls();
		}
	}


	/**
	 * Register cart controls controls.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->controls();
	}


	/**
	 * Register cart controls controls.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->controls();
	}



	/**
	 * Retrieve the widget name.
	 *
	 * @return string Widget name.
	 * @since  1.0.0
	 *
	 * @access public
	 */
	public function get_name() {
		return 'checkoutify-checkout';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @return string Widget title.
	 * @since  1.0.0
	 *
	 * @access public
	 */
	public function get_title() {
		return __( 'Checkoutify', 'checkoutify' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @return string Widget icon.
	 * @since  1.0.0
	 *
	 * @access public
	 * order-bump-settings
	 */
	public function get_icon() {
		return 'icon-checkoutify checkoutify-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @return array Widget categories.
	 * @since  1.0.0
	 *
	 * @access public
	 */
	public function get_categories() {
		return array( 'checkoutify' );
	}


	public function controls() {
		$this->start_controls_section(
			'section_content',
			array(
				'label' => __( 'Checkoutify', 'checkoutify' ),
			)
		);
	
		$this->add_control(
			'select_checkout',
			array(
				'label'       => __( 'Select Checkout', 'checkoutify' ),
				'type'        => \Elementor\Controls_Manager::SELECT,
				'default'     => '',
				'label_block' => true,
				'options'     => WidgetManager::getCheckouts(),
			)
		);
	}


	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings         = $this->get_settings_for_display();
		$selectedCheckout = isset( $settings['select_checkout'] ) ? $settings['select_checkout'] : '';
		?>
		<div class="rex-checkoutify">
		<?php echo do_shortcode( '[checkoutify checkout_id=' . $selectedCheckout . ']' ); ?>
		</div>
		<?php

	}
}
