<?php
/**
 * Gutenberg Manager class
 *
 * @package RexTheme\Checkoutify\Widgets
 */

namespace RexTheme\Checkoutify\Widgets\Gutenberg;

use RexTheme\Checkoutify\Common\Functions;
use RexTheme\Checkoutify\Common\Keys;
/**
 * Class Manager
 *
 * @package RexTheme\Checkoutify\Widgets
 */
class Manager {


    /**
     * Instance
     *
     * @since 1.0.0
     *
     * @access private
     * @static
     *
     * @var Manager The single instance of the class.
     */
    private static $instance = null;

    /**
     * Instance
     *
     * Ensures only one instance of the class is loaded or can be loaded.
     *
     * @return Manager An instance of the class.
     * @since  1.0.0
     *
     * @access public
     * @static
     */
    public static function instance() {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }
        return self::$instance;
    }


    /**
     * Constructor
     *
     * @since 1.0.0
     *
     * @access public
     */
    public function __construct() {
        add_action( 'init', array( $this, 'registerAssets' ) );
		add_action( 'init', array( $this, 'registerBlock' ) );
        add_action('enqueue_block_editor_assets', array($this, 'enqueueAssets'));
        add_action( 'wp_ajax_show_checkoutify_markup', array( $this, 'showCheckoutifyMarkup' ) );
    }


    /**
     * Register assets
     * 
     * @return void
     * @since 1.0.0
     */
    public function registerAssets(){
        if ( file_exists( CHECKOUTIFY_PATH . '/includes/Widgets/Gutenberg/build/dist/checkoutify.min.asset.php' ) ) {
			$dependency = require_once CHECKOUTIFY_PATH . '/includes/Widgets/Gutenberg/build/dist/checkoutify.min.asset.php';

			wp_register_script(
				'checkoutify-block-editor',
				CHECKOUTIFY_URL . '/includes/Widgets/Gutenberg/build/dist/checkoutify.min.js',
				$dependency[ 'dependencies' ],
				CHECKOUTIFY_VERSION,
				true
			);

			wp_register_style(
				'checkoutify-block-editor-style',
				CHECKOUTIFY_URL . '/includes/Widgets/Gutenberg/build/dist/checkoutify.css',
				array( 'wp-edit-blocks' ),
				CHECKOUTIFY_VERSION
			);
		}
    }


    /**
     * Register block
     * 
     * @return void
     * @since 1.0.0
     */
    public function registerBlock(){
        register_block_type(
			'checkoutify/checkout',
			array(
				'editor_script'   => 'checkoutify-block-editor-js',
				'editor_style'    => 'checkoutify-block-editor-style',
				'style'           => 'checkoutify-block-frontend-style',
				'render_callback' => array( $this, 'renderBlock' ),
			)
		);
    }


    /**
	 * Renders block markups
	 *
	 * @param array $attributes Block attributes.
	 *
	 * @return string|void
	 * @since 1.0.0
	 */
	public function renderBlock( $attributes ) {
		$html           = '';
		$checkoutId        = isset( $attributes['checkoutId'] ) ? $attributes['checkoutId'] : 0;
        $html .= do_shortcode( '[checkoutify checkout_id=' . $checkoutId . ']' );
		return $html;
	}


    /**
     * Enqueue block assets
     * 
     * @return void
     * @since 1.0.0
     */
    public function enqueueAssets(){
        wp_enqueue_script( 'checkoutify-block-editor' );
		wp_enqueue_style( 'checkoutify-block-editor-style' );
        $publishedCheckout = new \RexTheme\Checkoutify\Widgets\WidgetManager();
		wp_localize_script(
			'checkoutify-block-editor',
			'checkoutify_block_object',
			array(
				'siteUrl' => get_site_url(),
				'ajaxUrl' => admin_url( 'admin-ajax.php' ),
				'nonce'   => wp_create_nonce( 'checkoutify_gutenberg_rest' ),
				'theme'   => CHECKOUTIFY_URL,
				'publishedCheckout'   => $publishedCheckout->getPublishedCheckouts(),
			)
		);
    }


    /**
	 * Show checkout markups
	 *
	 * @return void
	 * @since 1.0.0
	 */
	public function showCheckoutifyMarkup() {
        check_ajax_referer('checkoutify_gutenberg_rest', 'security');
		if ( isset( $_POST['checkoutId'] ) && !empty( $_POST['checkoutId'] ) ) {
            
			$checkoutId     = wp_unslash(  $_POST['checkoutId'] );
			ob_start();
			$output  = do_shortcode( '[checkoutify checkout_id=' . $checkoutId . ']' );
			$output .= ob_get_clean();
			echo $output;
			wp_die();
		}
		echo esc_html( 'Please select a form' );
		wp_die();
	}

}

Manager::instance();