<?php
/**
 * Shortcodes.php
 *
 * This file defines the Shortcodes class, which manages shortcodes for the RexTheme Checkoutify plugin. It provides functionality to render the checkout content when the corresponding shortcode is used in WordPress posts or pages.
 *
 * @package RexTheme\Checkoutify\Widgets
 * @since 1.0.0
 */

namespace RexTheme\Checkoutify\Widgets;

use RexTheme\Checkoutify\Common\Keys;

/**
 * Class Shortcodes
 *
 * This class manages shortcodes for the RexTheme Checkoutify plugin.
 *
 * @package RexTheme\Checkoutify\Widgets
 */
class Shortcodes {

	/**
	 * Constructor for the Shortcodes class.
	 *
	 * Initializes the Shortcodes class and registers the defined shortcodes for the RexTheme Checkoutify plugin.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$shortcodes = array(
			Keys::CHECKOUTIFY_SHORTCODE_KEY => __CLASS__ . '::renderCheckout',
		);

		foreach ( $shortcodes as $shortcode => $function ) {
			add_shortcode( $shortcode, $function );
		}
	}

	/**
	 * Render checkout content.
	 *
	 * @param array $atts Shortcode attributes.
	 * @return string Rendered checkout content.
	 *
	 * @since 1.0.0
	 */
	public static function renderCheckout( $atts ) {
		$instance = new Checkout( (array) $atts );
		return $instance->getContent();
	}
}
