<?php
/**
 * Widgets Manager
 *
 * This class manages widgets for the RexTheme Checkoutify plugin.
 *
 * @package RexTheme\Checkoutify\Widgets
 */

namespace RexTheme\Checkoutify\Widgets;

use RexTheme\Checkoutify\Traits\Singleton;
use RexTheme\Checkoutify\Common\Functions;
use RexTheme\Checkoutify\Common\Keys;

/**
 * Widgets Manager
 *
 * This class manages widgets for the RexTheme Checkoutify plugin.
 *
 * @package RexTheme\Checkoutify\Widgets
 */
class WidgetManager {

	use Singleton;

	/**
	 * Widgets associated with the RexTheme Checkoutify plugin.
	 *
	 * @var array An array of widget managers keyed by builder name.
	 */
	private $widgets = array();

	/**
	 * Constructor for the RexThemeCheckoutify class.
	 *
	 * Initializes shortcodes and widget managers for the RexTheme Checkoutify plugin.
	 *
	 * @since 1.0.0
	 */
	public function init() {
		new Shortcodes();
		$builders = $this->getBuilders();
		foreach ( $builders as $builder ) {
			$class_name                = str_replace( '-', '', $builder );
			$class_name                = ucwords( $class_name );
			$class_name                = 'RexTheme\\Checkoutify\\Widgets\\'.$class_name .'\\Manager';
			$this->widgets[ $builder ] = $class_name::instance();
		}
	}

	/**
	 * Get the supported widget builders.
	 *
	 * @return array An array of supported widget builders.
	 *
	 * @since 1.0.0
	 */
	public function getBuilders() {
		$builders = array(
			'gutenberg'
		);

		if ( Functions::maybeElementorActivated() ) {
			array_push( $builders, 'elementor' );
		}
		
		if( Functions::maybeBricksActivated() ){
			array_push( $builders, 'bricks' );
		}

		return apply_filters( 'checkoutify/supported-builders', $builders );
	}


	/**
     * Get all published checkout 
     * 
     * @return array
     * @since 1.0.0
     */
    public static function getCheckouts()
    {
        $args = array(
            'post_type'      => 'rex_checkout', // Replace 'your_post_type' with the actual post type you want to query.
            'posts_per_page' => -1, // To retrieve all posts, set this to -1. You can set it to a specific number to limit the results.
            'orderby'        => 'date', // Order by post creation date.
            'order'          => 'DESC', // Descending order (most recent first).
            'post_status'    => array('publish'),
        );
        $posts = get_posts($args);

        if (!is_array($posts)) {
            return [];
        }

        if (is_array($posts) && empty($posts)) {
            return [];
        }

		$checkouts = [
			'' => 'Please select'
		];
        foreach ($posts as $post) {
            $post_title        = $post->post_title;
            $id                = $post->ID;
            $checkouts[$id] = $post_title;
        }
        return $checkouts;
    }


	/**
	 * Retrieves a collection of checkout items.
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	public function getPublishedCheckouts(){
		$args = array(
            'post_type'      => 'rex_checkout', // Replace 'your_post_type' with the actual post type you want to query.
            'posts_per_page' => -1, // To retrieve all posts, set this to -1. You can set it to a specific number to limit the results.
            'orderby'        => 'date', // Order by post creation date.
            'order'          => 'DESC', // Descending order (most recent first).
            'post_status'    => array('publish'),
        );
        $posts = get_posts($args);

        if (!is_array($posts)) {
            return [];
        }

        if (is_array($posts) && empty($posts)) {
            return [];
        }

		$checkouts = [];
		$checkouts[] = [
			'label' => 'Select checkout',
			'value' => '0'
		];
        foreach ($posts as $post) {
            $post_title        = $post->post_title;
            $id                = $post->ID;
            $checkouts[] = [
				'label' => $post_title,
				'value' => $id
			];
        }
		return $checkouts;
	}
}
