<?php
/**
 * Shipping Methods Display
 *
 * In 2.1 we show methods per package. This allows for multiple methods per order if so desired.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart-shipping.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 7.3.0
 */

defined( 'ABSPATH' ) || exit;

$checkout_settings = [];
$checkout_fields = [];
if (!isset($checkout_id)) {
    $checkout_id = \RexTheme\Checkoutify\Common\Functions::getCheckoutifyIdFromPost();
}

if (!$checkout_id) {
    $checkout_id = \RexTheme\Checkoutify\Common\Functions::getDefaultCheckout();
}

if (!$checkout_id) {
	global $post;
	$stepId = isset( $post->ID ) ? $post->ID : '';
	$funnelId = get_post_meta( $stepId, '_funnel_id', true );
	$checkout_id =  \RexTheme\Checkoutify\Common\Functions::maybeCheckoutAvailableByFunnelId($funnelId);
}

if (isset($checkout_id) && $checkout_id) {
    $instance = new \RexTheme\Checkoutify\Module\Checkout();
    $data = $instance->getSingleCheckout($checkout_id);
    if (is_array($data) && isset($data['metas']['checkoutify_checkout_data'])) {
        $checkout_fields = $data['metas']['checkoutify_checkout_data'];
    }

    if (is_array($data) && isset($data['metas']['checkoutify_checkout_settings'])) {
        $checkout_settings = $data['metas']['checkoutify_checkout_settings'];
    }
}
$subtotalStyle = "";
$shippingRadioStyle = "";

foreach ($checkout_fields as $step_index => $step) {
    if (count($step['sections']) > 0) {
        foreach ($step['sections'] as $section_index => $section) {
            foreach ($section['fields']['left'] as $field_index => $field) {
                $labelStyle = \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['label'] ) ? $field['styles']['label'] : []);
                $inputStyle = \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['input'] )  ? $field['styles']['input'] : []);
                if (isset( $field['key'] ) && 'order_details' === $field['key']) {
                    $subtotalStyle = \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['orderDetails']['subTotal'] ) ? $field['styles']['orderDetails']['subTotal'] : []) ;
                    $shippingRadioStyle = \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['orderDetails']['shipping'] ) ? $field['styles']['orderDetails']['shipping'] : [], 'radio');
                }
            }
            
            foreach ($section['fields']['right'] as $field_index => $field) {
                $labelStyle =  \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['label'] ) ? $field['styles']['label'] : []);
                $inputStyle =  \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['input'] ) ? $field['styles']['input'] : []);
                if ( isset( $field['key'] ) && 'order_details' === $field['key']) {
                    $subtotalStyle = \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['orderDetails']['subTotal'] )  ? $field['styles']['orderDetails']['subTotal'] : []);
                    $shippingRadioStyle = \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['orderDetails']['shipping'] ) ? $field['styles']['orderDetails']['shipping'] : [], 'radio');
                }
            }
        }
    }
}

$formatted_destination    = isset( $formatted_destination ) ? $formatted_destination : WC()->countries->get_formatted_address( $package['destination'], ', ' );
$has_calculated_shipping  = ! empty( $has_calculated_shipping );
$show_shipping_calculator = ! empty( $show_shipping_calculator );
$calculator_text          = '';

?>
<style id="rex-checkoutify-shipping-method-style">
    .rex-checkoutify-checkout .woocommerce-shipping-methods {
        padding: 0!important;
        margin: 0!important;
        display: flex;
        flex-flow: column;
        gap: 15px;
        list-style: none!important;
    }
    .rex-checkoutify-checkout .woocommerce-shipping-methods li {
        padding: 0!important;
        margin: 0!important;
    }
    .rex-checkoutify-checkout .woocommerce-shipping-methods li input[type="radio"] {
        display: none!important;
    }
    .rex-checkoutify-checkout .woocommerce-shipping-methods label.rex-checkoutify-radiobtn2 {
        display: flex!important;
        justify-content: flex-end!important;
        margin: 0!important;
        line-height: 1!important;
        padding: 0!important;
    }
    .rex-checkoutify-checkout .woocommerce-shipping-methods label.rex-checkoutify-radiobtn2:after,
    .rex-checkoutify-checkout .woocommerce-shipping-methods label.rex-checkoutify-radiobtn2:before {
        display: none!important;
    }
    .rex-checkoutify-checkout .woocommerce-shipping-methods label.rex-checkoutify-radiobtn2 .radio-box {
        <?php echo isset($shippingRadioStyle['styleBox']) ? $shippingRadioStyle['styleBox'] : ''; ?>
    }

    .rex-checkoutify-checkout .woocommerce-shipping-methods label.rex-checkoutify-radiobtn2 .radio-title {
        line-height: 1.2!important;
        <?php echo isset($shippingRadioStyle['styleTitle']) ? $shippingRadioStyle['styleTitle'] : ''; ?>
        text-indent: 0!important;
    }

    .rex-checkoutify-checkout .woocommerce-shipping-methods label.rex-checkoutify-radiobtn2 .radio-box .radio-box-inner {
        <?php echo isset($shippingRadioStyle['styleInner']) ? $shippingRadioStyle['styleInner'] : ''; ?>
    }

    .rex-checkoutify-checkout .woocommerce-shipping-methods input[type=radio]:checked + label.rex-checkoutify-radiobtn2 .radio-box {
        border-color: var(--activeBorderColor)!important;
        background: var(--activeBgColor)!important;
    }
    .rex-checkoutify-checkout .woocommerce-shipping-methods input[type=radio]:checked + label.rex-checkoutify-radiobtn2 .radio-box .radio-box-inner {
        transform: translate(-50%, -50%) scale(1);
    }

    
</style>

<tr class="woocommerce-shipping-totals shipping rex-checkoutify-shipping-method">
	<th style="<?php echo isset($subtotalStyle['style']) ? $subtotalStyle['style'] : ''; ?>" ><?php echo wp_kses_post( $package_name ); ?></th>
	<td style="<?php echo isset($subtotalStyle['style']) ? $subtotalStyle['style'] : ''; ?>" data-title="<?php echo esc_attr( $package_name ); ?>">
		<?php if ( $available_methods ) : ?>
			<ul id="shipping_method" class="woocommerce-shipping-methods">
				<?php foreach ( $available_methods as $method ) : ?>
					<li>
						<?php
						if ( 1 < count( $available_methods ) ) {
							printf( '<input type="radio" name="shipping_method[%1$d]" data-index="%1$d" id="shipping_method_%1$d_%2$s" value="%3$s" class="shipping_method" %4$s style="%5s"/>', $index, esc_attr( sanitize_title( $method->id ) ), esc_attr( $method->id ), checked( $method->id, $chosen_method, false ) ); // WPCS: XSS ok.
						} else {
							printf( '<input type="hidden" name="shipping_method[%1$d]" data-index="%1$d" id="shipping_method_%1$d_%2$s" value="%3$s" class="shipping_method" />', $index, esc_attr( sanitize_title( $method->id ) ), esc_attr( $method->id ) ); // WPCS: XSS ok.
						}
						printf( '<label class="rex-checkoutify-radiobtn2" for="shipping_method_%1$s_%2$s"><span class="radio-box"><span class="radio-box-inner"></span></span><span class="radio-title">%3$s</span></label>', $index, esc_attr( sanitize_title( $method->id ) ), wc_cart_totals_shipping_method_label( $method ) ); // WPCS: XSS ok.
						do_action( 'woocommerce_after_shipping_rate', $method, $index );
						?>
					</li>
				<?php endforeach; ?>
			</ul>
			<?php if ( is_cart() ) : ?>
				<p class="woocommerce-shipping-destination">
					<?php
					if ( $formatted_destination ) {
						// Translators: $s shipping destination.
						printf( esc_html__( 'Shipping to %s.', 'woocommerce' ) . ' ', '<strong>' . esc_html( $formatted_destination ) . '</strong>' );
						$calculator_text = esc_html__( 'Change address', 'woocommerce' );
					} else {
						echo wp_kses_post( apply_filters( 'woocommerce_shipping_estimate_html', __( 'Shipping options will be updated during checkout.', 'woocommerce' ) ) );
					}
					?>
				</p>
			<?php endif; ?>
			<?php
		elseif ( ! $has_calculated_shipping || ! $formatted_destination ) :
			if ( is_cart() && 'no' === get_option( 'woocommerce_enable_shipping_calc' ) ) {
				echo wp_kses_post( apply_filters( 'woocommerce_shipping_not_enabled_on_cart_html', __( 'Shipping costs are calculated during checkout.', 'woocommerce' ) ) );
			} else {
				echo wp_kses_post( apply_filters( 'woocommerce_shipping_may_be_available_html', __( 'Enter your address to view shipping options.', 'woocommerce' ) ) );
			}
		elseif ( ! is_cart() ) :
			echo wp_kses_post( apply_filters( 'woocommerce_no_shipping_available_html', __( 'There are no shipping options available. Please ensure that your address has been entered correctly, or contact us if you need any help.', 'woocommerce' ) ) );
		else :
			echo wp_kses_post(
				/**
				 * Provides a means of overriding the default 'no shipping available' HTML string.
				 *
				 * @since 3.0.0
				 *
				 * @param string $html                  HTML message.
				 * @param string $formatted_destination The formatted shipping destination.
				 */
				apply_filters(
					'woocommerce_cart_no_shipping_available_html',
					// Translators: $s shipping destination.
					sprintf( esc_html__( 'No shipping options were found for %s.', 'woocommerce' ) . ' ', '<strong>' . esc_html( $formatted_destination ) . '</strong>' ),
					$formatted_destination
				)
			);
			$calculator_text = esc_html__( 'Enter a different address', 'woocommerce' );
		endif;
		?>

		<?php if ( $show_package_details ) : ?>
			<?php echo '<p class="woocommerce-shipping-contents"><small>' . esc_html( $package_details ) . '</small></p>'; ?>
		<?php endif; ?>

		<?php if ( $show_shipping_calculator ) : ?>
			<?php woocommerce_shipping_calculator( $calculator_text ); ?>
		<?php endif; ?>
	</td>
</tr>
