<?php

/**
 * Review order table
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/review-order.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 5.2.0
 */



$checkout_settings = [];
$checkout_fields = [];
if (!isset($checkout_id)) {
    $checkout_id = \RexTheme\Checkoutify\Common\Functions::getCheckoutifyIdFromPost();
}

if (!$checkout_id) {
    $checkout_id = \RexTheme\Checkoutify\Common\Functions::getDefaultCheckout();
}

if (!$checkout_id) {
	global $post;
	$stepId = isset( $post->ID ) ? $post->ID : '';
	$funnelId = get_post_meta( $stepId, '_funnel_id', true );
	$checkout_id =  \RexTheme\Checkoutify\Common\Functions::maybeCheckoutAvailableByFunnelId($funnelId);
}
if (isset($checkout_id) && $checkout_id) {
    $instance = new \RexTheme\Checkoutify\Module\Checkout();
    $data = $instance->getSingleCheckout($checkout_id);
    if (is_array($data) && isset($data['metas']['checkoutify_checkout_data'])) {
        $checkout_fields = $data['metas']['checkoutify_checkout_data'];
    }

    if (is_array($data) && isset($data['metas']['checkoutify_checkout_settings'])) {
        $checkout_settings = $data['metas']['checkoutify_checkout_settings'];
    }
}
$order_button_text = 'Place Order';
defined('ABSPATH') || exit;


foreach ($checkout_fields as $step_index => $step) {
    if (count($step['sections']) > 0) {
        foreach ($step['sections'] as $section_index => $section) {
            foreach ($section['fields']['left'] as $field_index => $field) {
                ?> <div id="payment"  class="woocommerce-checkout-payment"> <?php 
                if (isset( $field['key'] ) && 'payment_method' === $field['key']) { 
                    if ( ! wp_doing_ajax() ) {
                        do_action( 'woocommerce_review_order_before_payment' );
                    }
                ?>
                        <?php 
                        if (\WC()->cart && \WC()->cart->needs_payment()) {
                            $available_gateways = \WC()->payment_gateways()->get_available_payment_gateways();
                            ?>
                            <ul class="wc_payment_methods payment_methods methods">
                                <?php
                                if (!empty($available_gateways)) {
                                    foreach ($available_gateways as $gateway) {
                                        ?>
                                        <li class="wc_payment_method payment_method_<?php echo esc_attr( $gateway->id ); ?>">
                                            <div class="rex-checkoutify-radio-group">
                                                <input id="payment_method_<?php echo esc_attr( $gateway->id ); ?>" type="radio" class="input-radio" name="payment_method" value="<?php echo esc_attr( $gateway->id ); ?>" <?php checked( $gateway->chosen, true ); ?> data-order_button_text="<?php echo esc_attr( 'ppcp-gateway' === $gateway->id ?  $gateway->order_button_text  : $order_button_text ); ?>" />

                                                <label for="payment_method_<?php echo esc_attr( $gateway->id ); ?>" class="rex-checkoutify-radiobtn2">
                                                    <span class="radio-box">
                                                        <span class="radio-box-inner"></span>
                                                    </span>
                                                    <span class="radio-title" >
                                                        <?php echo $gateway->get_title(); /* phpcs:ignore WordPress.XSS.EscapeOutput.OutputNotEscaped */ ?> <?php echo $gateway->get_icon(); /* phpcs:ignore WordPress.XSS.EscapeOutput.OutputNotEscaped */ ?>
                                                    </span>
                                                </label>
                                            </div>

                                            <?php if ( $gateway->has_fields() || $gateway->get_description() ) : ?>
                                                <div class="payment_box payment_method_<?php echo esc_attr( $gateway->id ); ?>" <?php if ( ! $gateway->chosen ) : /* phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace */ ?>style="display:none;"<?php endif; /* phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace */ ?> >
                                                    <div class="payment-box-inner">
                                                        <?php $gateway->payment_fields(); ?>
                                                    </div>
                                                </div>
                                            <?php endif; ?>
                                        </li>
                                        <?php 
                                    }
                                } else {
                                    echo '<li class="woocommerce-notice woocommerce-notice--info woocommerce-info">' . apply_filters('woocommerce_no_available_payment_methods_message', WC()->customer->get_billing_country() ? esc_html__('Sorry, it seems that there are no available payment methods for your state. Please contact us if you require assistance or wish to make alternate arrangements.', 'woocommerce') : esc_html__('Please fill in your details above to see available payment methods.', 'woocommerce')) . '</li>'; // @codingStandardsIgnoreLine
                                }

                                if( isset( $field['fieldType'] ) && 'payment-method' === $field['fieldType']) {
                                    $paymentSectionStyle = isset($field['styles']['payment']['section']) ? $field['styles']['payment']['section'] : '';
                                    $paymentBoxStyle = isset($field['styles']['payment']['box']) ? $field['styles']['payment']['box'] : '';
                                    $paymentRadioStyle = isset($field['styles']['payment']['radio']) ? $field['styles']['payment']['radio'] : '';
                                }
                                
                                ?>
                            </ul>

                            <style id="rex-checkouify-payment-method-style" type="text/css">
                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radio-group input[type="radio"] {
                                    display: none;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods {
                                    padding: 0;
                                    margin: 0 0 20px;
                                    list-style: none;
                                    border-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    border-radius: <?php echo isset($paymentSectionStyle['borderRadius']) ? $paymentSectionStyle['borderRadius'] : ''; ?>px!important;
                                    background-color: <?php echo isset($paymentSectionStyle['backgroundColor']) ? $paymentSectionStyle['backgroundColor'] : '' ?>!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_method {
                                    margin: 0;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment_box {
                                    padding: 0;
                                    background-color: transparent;
                                    border-radius: 4px;
                                    margin: 0;
                                    box-shadow: none;
                                    position: relative;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment_box:before,
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box:after {
                                    display: none;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment-box-inner {
                                    border-bottom-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-bottom-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-bottom-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    background-color: <?php echo isset($paymentBoxStyle['backgroundColor']) ? $paymentBoxStyle['backgroundColor'] : '' ?>!important;
                                    padding-top: <?php echo isset($paymentBoxStyle['paddingTop']) ? $paymentBoxStyle['paddingTop'] : '' ?>px!important;
                                    padding-right: <?php echo isset($paymentBoxStyle['paddingRight']) ? $paymentBoxStyle['paddingRight'] : '' ?>px!important;
                                    padding-bottom: <?php echo isset($paymentBoxStyle['paddingBottom']) ? $paymentBoxStyle['paddingBottom'] : '' ?>px!important;
                                    padding-left: <?php echo isset($paymentBoxStyle['paddingLeft']) ? $paymentBoxStyle['paddingLeft'] : '' ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_method:last-child .payment-box-inner {
                                    border-bottom-right-radius: <?php echo isset($paymentSectionStyle['borderRadius']) ? $paymentSectionStyle['borderRadius'] : ''; ?>px!important;
                                    border-bottom-left-radius: <?php echo isset($paymentSectionStyle['borderRadius']) ? $paymentSectionStyle['borderRadius'] : ''; ?>px!important;
                                    border-top-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-top-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-top-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    border-bottom: 0!important;
                                }
                                
                                .rex-checkoutify-checkout .wc_payment_methods .payment-box-inner p {
                                    margin: 0!important;
                                    padding: 0!important;
                                    font-size: <?php echo isset($paymentBoxStyle['fontSize']) ? $paymentBoxStyle['fontSize'] : '' ?>px!important;
                                    line-height: <?php echo isset($paymentBoxStyle['lineHeight']) ? $paymentBoxStyle['lineHeight'] : '' ?>!important;
                                    font-weight: <?php echo isset($paymentBoxStyle['fontWeight']) ? $paymentBoxStyle['fontWeight'] : '' ?>!important;
                                    color: <?php echo isset($paymentBoxStyle['color']) ? $paymentBoxStyle['color'] : '' ?>!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods {
                                    list-style: none;
                                    padding: 0;
                                    margin: 0;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment-box-inner p.testmode-info {
                                    margin-bottom: 10px !important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radio-group > label {
                                    cursor: pointer;
                                    display: flex;
                                    margin: 0;
                                    padding: 0;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radiobtn2:after,
                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radiobtn2:before {
                                    display: none!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radio-group {
                                    border-bottom-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-bottom-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-bottom-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    padding-top: <?php echo isset($paymentSectionStyle['paddingTop']) ? $paymentSectionStyle['paddingTop'] : '' ?>px!important;
                                    padding-right: <?php echo isset($paymentSectionStyle['paddingRight']) ? $paymentSectionStyle['paddingRight'] : '' ?>px!important;
                                    padding-bottom: <?php echo isset($paymentSectionStyle['paddingBottom']) ? $paymentSectionStyle['paddingBottom'] : '' ?>px!important;
                                    padding-left: <?php echo isset($paymentSectionStyle['paddingLeft']) ? $paymentSectionStyle['paddingLeft'] : '' ?>px!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .wc_payment_method:last-child .rex-checkoutify-radio-group {
                                    border-bottom: 0!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label,
                                .rex-checkoutify-checkout .wc_payment_methods .radio-title { 
                                    font-size: <?php echo isset($paymentRadioStyle['fontSize']) ? $paymentRadioStyle['fontSize'] : '' ?>px!important;
                                    line-height: <?php echo isset($paymentRadioStyle['lineHeight']) ? $paymentRadioStyle['lineHeight'] : '' ?>!important;
                                    font-weight: <?php echo isset($paymentRadioStyle['fontWeight']) ? $paymentRadioStyle['fontWeight'] : '' ?>!important;
                                    color: <?php echo isset($paymentRadioStyle['color']) ? $paymentRadioStyle['color'] : '' ?>!important;
                                    text-transform: <?php echo isset($paymentRadioStyle['textTransform']) ? $paymentRadioStyle['textTransform']['value'] : '' ?>!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .radio-box {
                                    border-width: <?php echo isset($paymentRadioStyle['borderWidth']) ? $paymentRadioStyle['borderWidth'] : ''; ?>px!important;
                                    border-style: <?php echo isset($paymentRadioStyle['borderStyle']) ? $paymentRadioStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-color: <?php echo isset($paymentRadioStyle['borderColor']) ? $paymentRadioStyle['borderColor'] : ''; ?>!important;
                                    border-radius: <?php echo isset($paymentRadioStyle['borderRadius']) ? $paymentRadioStyle['borderRadius'] : ''; ?>px!important;
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : '' ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['height']) ? $paymentRadioStyle['height'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['width']) ? $paymentRadioStyle['width'] : ''; ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods .radio-box .radio-box-inner {
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : ''; ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['activeIconHeight']) ? $paymentRadioStyle['activeIconHeight'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['activeIconWidth']) ? $paymentRadioStyle['activeIconWidth'] : ''; ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods input[type=radio]:checked + .rex-checkoutify-radiobtn2 .radio-box {
                                    border-color: <?php echo isset($paymentRadioStyle['activeBorderColor']) ? $paymentRadioStyle['activeBorderColor'] : '' ?>!important;
                                    background: <?php echo isset($paymentRadioStyle['activeBgColor']) ? $paymentRadioStyle['activeBgColor'] : '' ?>!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods input[type=radio]:checked + .rex-checkoutify-radiobtn2 .radio-box .radio-box-inner {
                                    transform: translate(-50%, -50%) scale(1);
                                }

                                /* ---saved payment method radio btn design--- */
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods > li {
                                    margin-bottom: 5px;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods > li:last-child {
                                    margin-bottom: 0;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > input[type=radio] {
                                    display: none;
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label {
                                    position: relative;
                                    cursor: pointer;
                                    padding-left: 26px;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label:before {
                                    content: "";
                                    position: absolute;
                                    top: 0;
                                    left: 0;
                                    transition: all 0.3s ease;

                                    border-width: <?php echo isset($paymentRadioStyle['borderWidth']) ? $paymentRadioStyle['borderWidth'] : ''; ?>px!important;
                                    border-style: <?php echo isset($paymentRadioStyle['borderStyle']) ? $paymentRadioStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-color: <?php echo isset($paymentRadioStyle['borderColor']) ? $paymentRadioStyle['borderColor'] : ''; ?>!important;
                                    border-radius: <?php echo isset($paymentRadioStyle['borderRadius']) ? $paymentRadioStyle['borderRadius'] : ''; ?>px!important;
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : '' ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['height']) ? $paymentRadioStyle['height'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['width']) ? $paymentRadioStyle['width'] : ''; ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label:after {
                                    content: "";
                                    border-radius: 100%;
                                    position: absolute;
                                    left: <?php echo $paymentRadioStyle['width']/2 ?>px;
                                    top: <?php echo $paymentRadioStyle['height']/2 ?>px;
                                    transform: translate(-50%, -50%) scale(0);
                                    transition: all 0.3s ease;
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : ''; ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['activeIconHeight']) ? $paymentRadioStyle['activeIconHeight'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['activeIconWidth']) ? $paymentRadioStyle['activeIconWidth'] : ''; ?>px!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > input[type=radio]:checked + label:before {
                                    border-color: <?php echo isset($paymentRadioStyle['activeBorderColor']) ? $paymentRadioStyle['activeBorderColor'] : '' ?>!important;
                                    background: <?php echo isset($paymentRadioStyle['activeBgColor']) ? $paymentRadioStyle['activeBgColor'] : '' ?>!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > input[type=radio]:checked + label:after {
                                    transform: translate(-50%, -50%) scale(1);
                                }
                                /* ---end saved payment method radio btn design--- */


                                /* ---input fieldset design--- */
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box fieldset {
                                    margin: 15px 0 0;
                                    border: none;
                                    padding: 0;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box .wc-payment-form .form-row {
                                    margin: 0;
                                    padding: 0;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box .wc-payment-form .form-row > label {
                                    font-size: 13px;
                                    line-height: 1.1;
                                    font-weight: 400;
                                    color: rgb(45, 49, 73);
                                    margin: 0 0 8px;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment_box .woocommerce-SavedPaymentMethods-saveNew > label {
                                    font-size: 14px;
                                    line-height: 1.3;
                                    font-weight: 400;
                                    color: rgb(45, 49, 73);
                                    text-transform: none;
                                }
                            </style>
                            <?php 
                        } 
                        ?>
                    <!-- </div> -->
                <?php
                }

                if ( isset( $field['key'] ) && 'place_order' === $field['key'] ) { ?>
                    <div class="">
                    <?php
                    /**
                     * Terms and conditions hook used to inject content.
                     *
                     * @since 3.4.0.
                     * @hooked wc_checkout_privacy_policy_text() Shows custom privacy policy text. Priority 20.
                     * @hooked wc_terms_and_conditions_page_content() Shows t&c page content. Priority 30.
                     */
                    do_action( 'woocommerce_checkout_terms_and_conditions' );
                    ?>
            
                    <?php if (wc_terms_and_conditions_checkbox_enabled()) : ?>
                        <p class="form-row validate-required">
                            <label class="woocommerce-form__label woocommerce-form__label-for-checkbox checkbox">
                                <input type="checkbox" class="woocommerce-form__input woocommerce-form__input-checkbox input-checkbox" name="terms" <?php checked(apply_filters('woocommerce_terms_is_checked_default', isset($_POST['terms'])), true); // WPCS: input var ok, csrf ok. ?> id="terms" />
                                <span class="woocommerce-terms-and-conditions-checkbox-text"><?php wc_terms_and_conditions_checkbox_text(); ?></span>&nbsp;<abbr class="required" title="<?php esc_attr_e('required', 'woocommerce'); ?>">*</abbr>
                            </label>
                            <input type="hidden" name="terms-field" value="1" />
                        </p>
                    <?php endif; 
                    do_action( 'woocommerce_checkout_after_terms_and_conditions' );
                    ?>
                    
                    <!-- if field tyle is place order -->
                    <?php
                    $placeOrderButtonStyle = \RexTheme\Checkoutify\Common\Functions::getStyles( isset( $field['styles']['button'] ) ? $field['styles']['button'] : []);
                    do_action('woocommerce_review_order_before_submit');
                    ?>
                    <button type="submit" class="rex-checkoutify-btn" name="woocommerce_checkout_place_order" id="place_order" style="<?php echo isset($placeOrderButtonStyle['style']) ? $placeOrderButtonStyle['style'] : "" ?>"><?php echo isset( $field['label'] ) ? $field['label'] : '' ?></button>
                    <?php wp_nonce_field('woocommerce-process_checkout', 'woocommerce-process-checkout-nonce'); 
                    do_action('woocommerce_review_order_after_submit');
                        if ( ! wp_doing_ajax() ) {
                            do_action( 'woocommerce_review_order_after_payment' );
                        }
            
                    ?>
                    </div>
            
                <?php }
                ?> </div> <?php 
            }

            foreach ($section['fields']['right'] as $field_index => $field) {
                if (isset( $field['key'] ) && 'payment_method' === $field['key']) {
                    ?>
                    <div id="payment" class="woocommerce-checkout-payment">
                        <?php 
                        if (\WC()->cart && \WC()->cart->needs_payment()) {
                            $available_gateways = \WC()->payment_gateways()->get_available_payment_gateways();
                            ?>
                            <div class="wc_payment_methods payment_methods methods">
                                <?php
                                if (!empty($available_gateways)) {
                                    foreach ($available_gateways as $gateway) {
                                        ?>
                                        <div class="wc_payment_method payment_method_<?php echo esc_attr( $gateway->id ); ?>">
                                            <div class="rex-checkoutify-radio-group">
                                                <input id="payment_method_<?php echo esc_attr( $gateway->id ); ?>" type="radio" class="input-radio" name="payment_method" value="<?php echo esc_attr( $gateway->id ); ?>" <?php checked( $gateway->chosen, true ); ?> data-order_button_text="<?php echo esc_attr( 'ppcp-gateway' === $gateway->id ?  $gateway->order_button_text  : $order_button_text ); ?>" />

                                                <label for="payment_method_<?php echo esc_attr( $gateway->id ); ?>" class="rex-checkoutify-radiobtn2">
                                                    <span class="radio-box">
                                                        <span class="radio-box-inner"></span>
                                                    </span>
                                                    <span class="radio-title" >
                                                        <?php echo $gateway->get_title(); /* phpcs:ignore WordPress.XSS.EscapeOutput.OutputNotEscaped */ ?> <?php echo $gateway->get_icon(); /* phpcs:ignore WordPress.XSS.EscapeOutput.OutputNotEscaped */ ?>
                                                    </span>
                                                </label>
                                            </div>

                                            <?php if ( $gateway->has_fields() || $gateway->get_description() ) : ?>
                                                <div class="payment_box payment_method_<?php echo esc_attr( $gateway->id ); ?>" <?php if ( ! $gateway->chosen ) : /* phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace */ ?>style="display:none;"<?php endif; /* phpcs:ignore Squiz.ControlStructures.ControlSignature.NewlineAfterOpenBrace */ ?> >
                                                    <div class="payment-box-inner">
                                                        <?php $gateway->payment_fields(); ?>
                                                    </div>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                        <?php 
                                    }
                                } else {
                                    echo '<li class="woocommerce-notice woocommerce-notice--info woocommerce-info">' . apply_filters('woocommerce_no_available_payment_methods_message', WC()->customer->get_billing_country() ? esc_html__('Sorry, it seems that there are no available payment methods for your state. Please contact us if you require assistance or wish to make alternate arrangements.', 'woocommerce') : esc_html__('Please fill in your details above to see available payment methods.', 'woocommerce')) . '</li>'; // @codingStandardsIgnoreLine
                                }

                                if( isset( $field['fieldType'] ) && 'payment-method' === $field['fieldType']) {
                                    $paymentSectionStyle = isset($field['styles']['payment']['section']) ? $field['styles']['payment']['section'] : '';
                                    $paymentBoxStyle = isset($field['styles']['payment']['box']) ? $field['styles']['payment']['box'] : '';
                                    $paymentRadioStyle = isset($field['styles']['payment']['radio']) ? $field['styles']['payment']['radio'] : '';
                                }
                                
                                ?>
                            </div>

                            <style id="rex-checkouify-payment-method-style" type="text/css">
                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radio-group input[type="radio"] {
                                    display: none;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods {
                                    padding: 0;
                                    margin: 0 0 20px;
                                    list-style: none;
                                    border-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    border-radius: <?php echo isset($paymentSectionStyle['borderRadius']) ? $paymentSectionStyle['borderRadius'] : ''; ?>px!important;
                                    background-color: <?php echo isset($paymentSectionStyle['backgroundColor']) ? $paymentSectionStyle['backgroundColor'] : '' ?>!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_method {
                                    margin: 0;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment_box {
                                    padding: 0;
                                    background-color: transparent;
                                    border-radius: 4px;
                                    margin: 0;
                                    box-shadow: none;
                                    position: relative;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment_box:before,
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box:after {
                                    display: none;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment-box-inner {
                                    border-bottom-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-bottom-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-bottom-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    background-color: <?php echo isset($paymentBoxStyle['backgroundColor']) ? $paymentBoxStyle['backgroundColor'] : '' ?>!important;
                                    padding-top: <?php echo isset($paymentBoxStyle['paddingTop']) ? $paymentBoxStyle['paddingTop'] : '' ?>px!important;
                                    padding-right: <?php echo isset($paymentBoxStyle['paddingRight']) ? $paymentBoxStyle['paddingRight'] : '' ?>px!important;
                                    padding-bottom: <?php echo isset($paymentBoxStyle['paddingBottom']) ? $paymentBoxStyle['paddingBottom'] : '' ?>px!important;
                                    padding-left: <?php echo isset($paymentBoxStyle['paddingLeft']) ? $paymentBoxStyle['paddingLeft'] : '' ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_method:last-child .payment-box-inner {
                                    border-bottom-right-radius: <?php echo isset($paymentSectionStyle['borderRadius']) ? $paymentSectionStyle['borderRadius'] : ''; ?>px!important;
                                    border-bottom-left-radius: <?php echo isset($paymentSectionStyle['borderRadius']) ? $paymentSectionStyle['borderRadius'] : ''; ?>px!important;
                                    border-top-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-top-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-top-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    border-bottom: 0!important;
                                }
                                
                                .rex-checkoutify-checkout .wc_payment_methods .payment-box-inner p {
                                    margin: 0!important;
                                    padding: 0!important;
                                    font-size: <?php echo isset($paymentBoxStyle['fontSize']) ? $paymentBoxStyle['fontSize'] : '' ?>px!important;
                                    line-height: <?php echo isset($paymentBoxStyle['lineHeight']) ? $paymentBoxStyle['lineHeight'] : '' ?>!important;
                                    font-weight: <?php echo isset($paymentBoxStyle['fontWeight']) ? $paymentBoxStyle['fontWeight'] : '' ?>!important;
                                    color: <?php echo isset($paymentBoxStyle['color']) ? $paymentBoxStyle['color'] : '' ?>!important;
                                   
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods {
                                    list-style: none;
                                    padding: 0;
                                    margin: 0;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment-box-inner p.testmode-info {
                                    margin-bottom: 10px !important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radio-group > label {
                                    cursor: pointer;
                                    display: flex;
                                    margin: 0;
                                    padding: 0;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radiobtn2:after,
                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radiobtn2:before {
                                    display: none!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .rex-checkoutify-radio-group {
                                    border-bottom-width: <?php echo isset($paymentSectionStyle['borderWidth']) ? $paymentSectionStyle['borderWidth'] : ''; ?>px!important;
                                    border-bottom-style: <?php echo isset($paymentSectionStyle['borderStyle']) ? $paymentSectionStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-bottom-color: <?php echo isset($paymentSectionStyle['borderColor']) ? $paymentSectionStyle['borderColor'] : ''; ?>!important;
                                    padding-top: <?php echo isset($paymentSectionStyle['paddingTop']) ? $paymentSectionStyle['paddingTop'] : '' ?>px!important;
                                    padding-right: <?php echo isset($paymentSectionStyle['paddingRight']) ? $paymentSectionStyle['paddingRight'] : '' ?>px!important;
                                    padding-bottom: <?php echo isset($paymentSectionStyle['paddingBottom']) ? $paymentSectionStyle['paddingBottom'] : '' ?>px!important;
                                    padding-left: <?php echo isset($paymentSectionStyle['paddingLeft']) ? $paymentSectionStyle['paddingLeft'] : '' ?>px!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .wc_payment_method:last-child .rex-checkoutify-radio-group {
                                    border-bottom: 0!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label,
                                .rex-checkoutify-checkout .wc_payment_methods .radio-title { 
                                    font-size: <?php echo isset($paymentRadioStyle['fontSize']) ? $paymentRadioStyle['fontSize'] : '' ?>px!important;
                                    line-height: <?php echo isset($paymentRadioStyle['lineHeight']) ? $paymentRadioStyle['lineHeight'] : '' ?>!important;
                                    font-weight: <?php echo isset($paymentRadioStyle['fontWeight']) ? $paymentRadioStyle['fontWeight'] : '' ?>!important;
                                    color: <?php echo isset($paymentRadioStyle['color']) ? $paymentRadioStyle['color'] : '' ?>!important;
                                    text-transform: <?php echo isset($paymentRadioStyle['textTransform']) ? $paymentRadioStyle['textTransform']['value'] : '' ?>!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .radio-box {
                                    border-width: <?php echo isset($paymentRadioStyle['borderWidth']) ? $paymentRadioStyle['borderWidth'] : ''; ?>px!important;
                                    border-style: <?php echo isset($paymentRadioStyle['borderStyle']) ? $paymentRadioStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-color: <?php echo isset($paymentRadioStyle['borderColor']) ? $paymentRadioStyle['borderColor'] : ''; ?>!important;
                                    border-radius: <?php echo isset($paymentRadioStyle['borderRadius']) ? $paymentRadioStyle['borderRadius'] : ''; ?>px!important;
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : '' ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['height']) ? $paymentRadioStyle['height'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['width']) ? $paymentRadioStyle['width'] : ''; ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods .radio-box .radio-box-inner {
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : ''; ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['activeIconHeight']) ? $paymentRadioStyle['activeIconHeight'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['activeIconWidth']) ? $paymentRadioStyle['activeIconWidth'] : ''; ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods input[type=radio]:checked + .rex-checkoutify-radiobtn2 .radio-box {
                                    border-color: <?php echo isset($paymentRadioStyle['activeBorderColor']) ? $paymentRadioStyle['activeBorderColor'] : '' ?>!important;
                                    background: <?php echo isset($paymentRadioStyle['activeBgColor']) ? $paymentRadioStyle['activeBgColor'] : '' ?>!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods input[type=radio]:checked + .rex-checkoutify-radiobtn2 .radio-box .radio-box-inner {
                                    transform: translate(-50%, -50%) scale(1);
                                }

                                /* ---saved payment method radio btn design--- */
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods > li {
                                    margin-bottom: 5px;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods > li:last-child {
                                    margin-bottom: 0;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > input[type=radio] {
                                    display: none;
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label {
                                    position: relative;
                                    cursor: pointer;
                                    padding-left: 26px;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label:before {
                                    content: "";
                                    position: absolute;
                                    top: 0;
                                    left: 0;
                                    transition: all 0.3s ease;

                                    border-width: <?php echo isset($paymentRadioStyle['borderWidth']) ? $paymentRadioStyle['borderWidth'] : ''; ?>px!important;
                                    border-style: <?php echo isset($paymentRadioStyle['borderStyle']) ? $paymentRadioStyle['borderStyle']['value'] : ''; ?>!important;
                                    border-color: <?php echo isset($paymentRadioStyle['borderColor']) ? $paymentRadioStyle['borderColor'] : ''; ?>!important;
                                    border-radius: <?php echo isset($paymentRadioStyle['borderRadius']) ? $paymentRadioStyle['borderRadius'] : ''; ?>px!important;
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : '' ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['height']) ? $paymentRadioStyle['height'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['width']) ? $paymentRadioStyle['width'] : ''; ?>px!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > label:after {
                                    content: "";
                                    border-radius: 100%;
                                    position: absolute;
                                    left: <?php echo $paymentRadioStyle['width']/2 ?>px;
                                    top: <?php echo $paymentRadioStyle['height']/2 ?>px;
                                    transform: translate(-50%, -50%) scale(0);
                                    transition: all 0.3s ease;
                                    background-color: <?php echo isset($paymentRadioStyle['backgroundColor']) ? $paymentRadioStyle['backgroundColor'] : ''; ?>!important;
                                    height: <?php echo isset($paymentRadioStyle['activeIconHeight']) ? $paymentRadioStyle['activeIconHeight'] : ''; ?>px!important;
                                    width: <?php echo isset($paymentRadioStyle['activeIconWidth']) ? $paymentRadioStyle['activeIconWidth'] : ''; ?>px!important;
                                }

                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > input[type=radio]:checked + label:before {
                                    border-color: <?php echo isset($paymentRadioStyle['activeBorderColor']) ? $paymentRadioStyle['activeBorderColor'] : '' ?>!important;
                                    background: <?php echo isset($paymentRadioStyle['activeBgColor']) ? $paymentRadioStyle['activeBgColor'] : '' ?>!important;
                                }
                                .rex-checkoutify-checkout .wc_payment_method .payment-box-inner ul.woocommerce-SavedPaymentMethods li > input[type=radio]:checked + label:after {
                                    transform: translate(-50%, -50%) scale(1);
                                }
                                /* ---end saved payment method radio btn design--- */
                                

                                /* ---input fieldset design--- */
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box fieldset {
                                    margin: 15px 0 0;
                                    border: none;
                                    padding: 0;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box .wc-payment-form .form-row {
                                    margin: 0;
                                    padding: 0;
                                }
                                .rex-checkoutify-checkout .wc_payment_methods .payment_box .wc-payment-form .form-row > label {
                                    font-size: 13px;
                                    line-height: 1.1;
                                    font-weight: 400;
                                    color: rgb(45, 49, 73);
                                    margin: 0 0 8px;
                                }

                                .rex-checkoutify-checkout .wc_payment_methods .payment_box .woocommerce-SavedPaymentMethods-saveNew > label {
                                    font-size: 14px;
                                    line-height: 1.3;
                                    font-weight: 400;
                                    color: rgb(45, 49, 73);
                                    text-transform: none;
                                }
                            </style>
                            <?php 
                        } 
                        ?>
                    </div>
                <?php
                }
            }
        }
    }
}