<?php

/**
 * Review order table
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/checkout/review-order.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 5.2.0
 */



$checkout_settings = [];
$checkout_fields = [];
if (!isset($checkout_id)) {
    $checkout_id = \RexTheme\Checkoutify\Common\Functions::getCheckoutifyIdFromPost();
}

if (!$checkout_id) {
    $checkout_id = \RexTheme\Checkoutify\Common\Functions::getDefaultCheckout();
}

if (!$checkout_id) {
	global $post;
	$stepId = isset( $post->ID ) ? $post->ID : '';
	$funnelId = get_post_meta( $stepId, '_funnel_id', true );
	$checkout_id =  \RexTheme\Checkoutify\Common\Functions::maybeCheckoutAvailableByFunnelId($funnelId);
}

if (isset($checkout_id) && $checkout_id) {
    $instance = new \RexTheme\Checkoutify\Module\Checkout();
    $data = $instance->getSingleCheckout($checkout_id);
    if (is_array($data) && isset($data['metas']['checkoutify_checkout_data'])) {
        $checkout_fields = $data['metas']['checkoutify_checkout_data'];
    }

    if (is_array($data) && isset($data['metas']['checkoutify_checkout_settings'])) {
        $checkout_settings = $data['metas']['checkoutify_checkout_settings'];
    }
}

defined('ABSPATH') || exit;
do_action('wpfunnel_review_order_before_cart_contents');
foreach ($checkout_fields as $step_index => $step) {
    if (count($step['sections']) > 0) {
        foreach ($step['sections'] as $section_index => $section) {
            foreach ($section['fields']['left'] as $field_index => $field) {
                $labelStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['label'] ) ? $field['styles']['label'] : []);
                $inputStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['input'] ) ? $field['styles']['input'] : []);
                if (isset( $field['key'] ) && 'order_details' === $field['key']) { ?>

                    <table class="order-table woocommerce-checkout-review-order-table">
                        <tbody>
                            <?php
                            $orderDetailsStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['orderDetails']['product'] ) ? $field['styles']['orderDetails']['product'] : []);

                            if (WC()->cart) {
                                foreach (\WC()->cart->get_cart() as $cart_item_key => $cart_item) {
                                    $_product = apply_filters('woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key);

                                    if ($_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters('woocommerce_checkout_cart_item_visible', true, $cart_item, $cart_item_key)) {
                            ?>
                                        <tr class="cart-item">
                                            <td class="product-name">
                                                <div class="product-name-wrapper">
                                                    <?php if (isset( $field['styles']['orderDetails']['product']['productImg'] ) && $field['styles']['orderDetails']['product']['productImg']) {
                                                        $product_image = wp_get_attachment_image_src(get_post_thumbnail_id($_product->get_id()), 'single-post-thumbnail');
                                                    ?>
                                                        <div class="product-img" style="border-color: <?php echo isset($field['styles']['orderDetails']['product']['borderColor']) ?? $field['styles']['orderDetails']['product']['borderColor'] ?>;">
                                                            <img src="<?php echo is_array($product_image) ? $product_image[0] : '' ?>" alt="Product image">
                                                            <span class="count">
                                                                <?php
                                                                echo $cart_item['quantity'];
                                                                ?>
                                                            </span>
                                                        </div>
                                                    <?php } ?>

                                                    <p class="title" style="<?php echo isset($orderDetailsStyle['style']) ? $orderDetailsStyle['style'] : ''; ?>">
                                                        <?php echo wp_kses_post(apply_filters('woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key)) . '&nbsp;'; ?>
                                                        <?php
                                                        if (!$field['styles']['orderDetails']['product']['productImg']) {
                                                            echo '<span>x ' . $cart_item['quantity'] . '</span>';
                                                        }
                                                        ?>
                                                    </p>
                                                </div>
                                            </td>

                                            <td class="product-total" style="<?php echo isset($orderDetailsStyle['style']) ? $orderDetailsStyle['style'] : ''; ?>">
                                                <?php echo apply_filters('woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal($_product, $cart_item['quantity']), $cart_item, $cart_item_key); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped 
                                                ?>
                                            </td>
                                        </tr>
                            <?php
                                    }
                                }
                            }
                            ?>
                        </tbody>

                        <tfoot>
                            <?php
                            $subtotalStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['orderDetails']['subTotal'] ) ? $field['styles']['orderDetails']['subTotal'] : []);
                            $totalStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['orderDetails']['total'] ) ? $field['styles']['orderDetails']['total'] : []);
                            ?>
                            <tr class="cart-subtotal">
                                <td class="subtotal-title " style="<?php echo isset($subtotalStyle['style']) ? $subtotalStyle['style'] : ''; ?>">Subtotal</td>
                                <td class="subtotal-value" style="<?php echo isset($subtotalStyle['style']) ? $subtotalStyle['style'] : ''; ?>"><?php WC()->cart ? wc_cart_totals_subtotal_html() : 0.00; ?></td>
                            </tr>
                            <?php
                            if (WC()->cart) :
                                foreach (WC()->cart->get_coupons() as $code => $coupon) : ?>
                                    <tr class="cart-discount coupon-<?php echo esc_attr(sanitize_title($code)); ?>">
                                        <td><?php wc_cart_totals_coupon_label($coupon); ?></td>
                                        <td><?php wc_cart_totals_coupon_html($coupon); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                            ?>
                            <tr class="shipping">
                                <!-- <td class="">Shipping</td> -->
                                <?php if (WC()->cart && WC()->cart->needs_shipping() && WC()->cart->show_shipping()) : ?>

                                    <?php do_action( 'woocommerce_review_order_before_shipping' ); ?>

                                    <?php wc_cart_totals_shipping_html(); ?>

                                    <?php do_action( 'woocommerce_review_order_after_shipping' ); ?>

                                <?php endif; ?>
                                <?php if (WC()->cart) :
                                    foreach (WC()->cart->get_fees() as $fee) : ?>
                            <tr class="fee">
                                <th><?php echo esc_html($fee->name); ?></th>
                                <td><?php wc_cart_totals_fee_html($fee); ?></td>
                            </tr>
                    <?php
                                    endforeach;
                                endif;
                    ?>

                    <?php if (wc_tax_enabled() &&  WC()->cart && !WC()->cart->display_prices_including_tax()) : ?>
                        <?php if ('itemized' === get_option('woocommerce_tax_total_display')) : ?>
                            <?php foreach (WC()->cart->get_tax_totals() as $code => $tax) : // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited 
                            ?>
                                <tr class="tax-rate tax-rate-<?php echo esc_attr(sanitize_title($code)); ?>">
                                    <th><?php echo esc_html($tax->label); ?></th>
                                    <td><?php echo wp_kses_post($tax->formatted_amount); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else : ?>
                            <tr class="tax-total">
                                <th><?php echo esc_html(WC()->countries->tax_or_vat()); ?></th>
                                <td><?php wc_cart_totals_taxes_total_html(); ?></td>
                            </tr>
                        <?php endif; ?>
                    <?php endif; ?>
                    </tr>

                    <tr class="total">
                        <th class="" style="<?php echo isset($totalStyle['style']) ? $totalStyle['style'] : ''; ?>">Total</th>
                        <th class="" style="<?php echo isset($totalStyle['style']) ? $totalStyle['style'] : ''; ?>"><?php WC()->cart ?  wc_cart_totals_order_total_html() : 0.00; ?></th>
                    </tr>
                        </tfoot>
                    </table>
<?php }
            }
            foreach ($section['fields']['right'] as $field_index => $field) {
                $labelStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['label'] ) ? $field['styles']['label'] : []);
                $inputStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['input'] ) ? $field['styles']['input'] : []);
                if (isset( $field['key'] ) && 'order_details' === $field['key']) {
?>

                    <table class="order-table woocommerce-checkout-review-order-table">
                        <tbody>
                            <?php
                            $orderDetailsStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['orderDetails']['product'] ) ? $field['styles']['orderDetails']['product'] : []);

                            if (WC()->cart) {
                                foreach (\WC()->cart->get_cart() as $cart_item_key => $cart_item) {
                                    $_product = apply_filters('woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key);

                                    if ($_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters('woocommerce_checkout_cart_item_visible', true, $cart_item, $cart_item_key)) {
                            ?>
                                        <tr class="cart-item">
                                            <td class="product-name">
                                                <div class="product-name-wrapper">
                                                    <?php if ($field['styles']['orderDetails']['product']['productImg']) {
                                                        $product_image = wp_get_attachment_image_src(get_post_thumbnail_id($_product->get_id()), 'single-post-thumbnail');
                                                    ?>
                                                        <div class="product-img" style="border-color: <?php echo isset($field['styles']['orderDetails']['product']['borderColor']) ?? $field['styles']['orderDetails']['product']['borderColor'] ?>;">
                                                            <img src="<?php echo is_array($product_image) ? $product_image[0] : '' ?>" alt="Product image">
                                                            <span class="count">
                                                                <?php
                                                                echo $cart_item['quantity'];
                                                                ?>
                                                            </span>
                                                        </div>
                                                    <?php } ?>

                                                    <p class="title" style="<?php echo isset($orderDetailsStyle['style']) ? $orderDetailsStyle['style'] : ''; ?>">
                                                        <?php echo wp_kses_post(apply_filters('woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key)) . '&nbsp;'; ?>
                                                        <?php
                                                        if (!$field['styles']['orderDetails']['product']['productImg']) {
                                                            echo '<span>x ' . $cart_item['quantity'] . '</span>';
                                                        }
                                                        ?>
                                                    </p>
                                                </div>
                                            </td>

                                            <td class="product-total" style="<?php echo isset($orderDetailsStyle['style']) ? $orderDetailsStyle['style'] : ''; ?>">
                                                <?php echo apply_filters('woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal($_product, $cart_item['quantity']), $cart_item, $cart_item_key); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped 
                                                ?>
                                            </td>
                                        </tr>
                            <?php
                                    }
                                }
                            }
                            ?>
                        </tbody>

                        <tfoot>
                            <?php
                            $subtotalStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['orderDetails']['subTotal'] ) ? $field['styles']['orderDetails']['subTotal'] : []);
                            $totalStyle = \RexTheme\Checkoutify\Common\Functions::getStyles(isset( $field['styles']['orderDetails']['total'] ) ? $field['styles']['orderDetails']['total'] : []);
                            ?>
                            <tr class="cart-subtotal">
                                <td class="subtotal-title" style="<?php echo isset($subtotalStyle['style']) ? $subtotalStyle['style'] : ''; ?>">Subtotal</td>
                                <td class="subtotal-value" style="<?php echo isset($subtotalStyle['style']) ? $subtotalStyle['style'] : ''; ?>"><?php WC()->cart ? wc_cart_totals_subtotal_html() : 0.00; ?></td>
                            </tr>
                            <?php
                            if (WC()->cart) :
                                foreach (WC()->cart->get_coupons() as $code => $coupon) : ?>
                                    <tr class="cart-discount coupon-<?php echo esc_attr(sanitize_title($code)); ?>">
                                        <td><?php wc_cart_totals_coupon_label($coupon); ?></td>
                                        <td><?php wc_cart_totals_coupon_html($coupon); ?></td>
                                    </tr>
                            <?php endforeach;
                            endif;
                            ?>
                            <tr class="shipping">
                                <!-- <td class="">Shipping</td> -->
                                <?php if (WC()->cart && WC()->cart->needs_shipping() && WC()->cart->show_shipping()) : ?>

                                    <?php do_action('woocommerce_review_order_before_shipping'); ?>

                                    <?php wc_cart_totals_shipping_html(); ?>

                                    <?php do_action('woocommerce_review_order_after_shipping'); ?>

                                <?php endif; ?>
                                <?php if (WC()->cart) :
                                    foreach (WC()->cart->get_fees() as $fee) : ?>
                            <tr class="fee">
                                <th><?php echo esc_html($fee->name); ?></th>
                                <td><?php wc_cart_totals_fee_html($fee); ?></td>
                            </tr>
                    <?php
                                    endforeach;
                                endif;
                    ?>

                    <?php if (wc_tax_enabled() &&  WC()->cart && !WC()->cart->display_prices_including_tax()) : ?>
                        <?php if ('itemized' === get_option('woocommerce_tax_total_display')) : ?>
                            <?php foreach (WC()->cart->get_tax_totals() as $code => $tax) : // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited 
                            ?>
                                <tr class="tax-rate tax-rate-<?php echo esc_attr(sanitize_title($code)); ?>">
                                    <th><?php echo esc_html($tax->label); ?></th>
                                    <td><?php echo wp_kses_post($tax->formatted_amount); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else : ?>
                            <tr class="tax-total">
                                <th><?php echo esc_html(WC()->countries->tax_or_vat()); ?></th>
                                <td><?php wc_cart_totals_taxes_total_html(); ?></td>
                            </tr>
                        <?php endif; ?>
                    <?php endif; ?>
                    </tr>

                    <tr class="total">
                        <th class="" style="<?php echo isset($totalStyle['style']) ? $totalStyle['style'] : ''; ?>">Total</th>
                        <th class="" style="<?php echo isset($totalStyle['style']) ? $totalStyle['style'] : ''; ?>"><?php WC()->cart ?  wc_cart_totals_order_total_html() : 0.00; ?></th>
                    </tr>
                        </tfoot>
                    </table>
<?php }
            }
        }
    }
}
?>