<?php
/**
 * Login form
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/global/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     7.0.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( is_user_logged_in() ) {
	return;
}

global $loginLabelPosition;

?>
<form class="woocommerce-form woocommerce-form-login login" method="post" <?php echo ( $hidden ) ? 'style="display:none;"' : ''; ?> >

    <?php do_action( 'woocommerce_login_form_start' ); ?>

    <?php echo ( $message ) ? wpautop( wptexturize( $message ) ) : ''; // @codingStandardsIgnoreLine ?>
    
    <div class="login-form-wrapper">
        <div class="rex-checkoutify-input-group input-fields">
            <div class="rex-checkoutify-form-group username label-<?php echo $loginLabelPosition; ?>">
                <label class="field-name" for="username"><?php esc_html_e( 'Username or email', 'woocommerce' ); ?>&nbsp;<span class="required">*</span></label>
                <input type="text" class="input-text rex-checkoutify-input" name="username" id="username" autocomplete="username" />
            </div>

            <div class="rex-checkoutify-form-group password label-<?php echo $loginLabelPosition; ?>">
                <label class="field-name" for="password"><?php esc_html_e( 'Password', 'woocommerce' ); ?>&nbsp;<span class="required">*</span></label>
                <input class="input-text woocommerce-Input rex-checkoutify-input" type="password" name="password" id="password" autocomplete="current-password" />
            </div>
        </div>

        <?php do_action( 'woocommerce_login_form' ); ?>

        <div class="rex-checkoutify-input-group from-btn">
            <?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
            <input type="hidden" name="redirect" value="<?php echo esc_url( $redirect ); ?>" />
            <button type="submit" class="woocommerce-button button woocommerce-form-login__submit<?php echo esc_attr( wc_wp_theme_get_element_class_name( 'button' ) ? ' ' . wc_wp_theme_get_element_class_name( 'button' ) : '' ); ?>" name="login" value="<?php esc_attr_e( 'Login', 'woocommerce' ); ?>"><?php esc_html_e( 'Login', 'woocommerce' ); ?></button>

            <label class="rex-checkoutify-checkbox2 woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme">
                <input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" />

                <span class="checkbox-box">
                    <span class="checkbox-box-inner">
                        <svg fill="none" width="10" height="10" viewBox="0 0 12 10" xmlns="http://www.w3.org/2000/svg"><path fill="#fff" d="M5.538 9.635a.23.23 0 01-.17-.074L.8 4.618a.23.23 0 01.169-.387h2.2a.23.23 0 01.173.08L4.87 6.066c.165-.353.485-.94 1.045-1.656.83-1.058 2.37-2.614 5.008-4.019a.23.23 0 01.25.386c-.01.008-1.027.809-2.197 2.275C7.898 4.403 6.466 6.61 5.762 9.46a.23.23 0 01-.224.175z"/></svg>
                    </span>
                </span>
                <span class="checkbox-title whitespace-nowrap"><?php esc_html_e( 'Remember me', 'woocommerce' ); ?></span>
            </label>
        </div>

        <div class="lost-password">
            <a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'woocommerce' ); ?></a>
        </div>
    </div>

    <?php do_action( 'woocommerce_login_form_end' ); ?>
</form>

